#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandSavingPassQueryModel(object):

    def __init__(self):
        self._ch_info = None
        self._pid = None
        self._sol_code = None
        self._user_id = None

    @property
    def ch_info(self):
        return self._ch_info

    @ch_info.setter
    def ch_info(self, value):
        self._ch_info = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def sol_code(self):
        return self._sol_code

    @sol_code.setter
    def sol_code(self, value):
        self._sol_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ch_info:
            if hasattr(self.ch_info, 'to_alipay_dict'):
                params['ch_info'] = self.ch_info.to_alipay_dict()
            else:
                params['ch_info'] = self.ch_info
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.sol_code:
            if hasattr(self.sol_code, 'to_alipay_dict'):
                params['sol_code'] = self.sol_code.to_alipay_dict()
            else:
                params['sol_code'] = self.sol_code
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandSavingPassQueryModel()
        if 'ch_info' in d:
            o.ch_info = d['ch_info']
        if 'pid' in d:
            o.pid = d['pid']
        if 'sol_code' in d:
            o.sol_code = d['sol_code']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAntarchiveFaceIdentifyModel(object):

    def __init__(self):
        self._biz_scene = None
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._portrait = None
        self._portrait_auth_rect = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def portrait(self):
        return self._portrait

    @portrait.setter
    def portrait(self, value):
        self._portrait = value
    @property
    def portrait_auth_rect(self):
        return self._portrait_auth_rect

    @portrait_auth_rect.setter
    def portrait_auth_rect(self, value):
        self._portrait_auth_rect = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.portrait:
            if hasattr(self.portrait, 'to_alipay_dict'):
                params['portrait'] = self.portrait.to_alipay_dict()
            else:
                params['portrait'] = self.portrait
        if self.portrait_auth_rect:
            if hasattr(self.portrait_auth_rect, 'to_alipay_dict'):
                params['portrait_auth_rect'] = self.portrait_auth_rect.to_alipay_dict()
            else:
                params['portrait_auth_rect'] = self.portrait_auth_rect
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAntarchiveFaceIdentifyModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'portrait' in d:
            o.portrait = d['portrait']
        if 'portrait_auth_rect' in d:
            o.portrait_auth_rect = d['portrait_auth_rect']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncPidUnwriteoffQueryModel(object):

    def __init__(self):
        self._business_scene = None
        self._ip_role_id = None

    @property
    def business_scene(self):
        return self._business_scene

    @business_scene.setter
    def business_scene(self, value):
        self._business_scene = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_scene:
            if hasattr(self.business_scene, 'to_alipay_dict'):
                params['business_scene'] = self.business_scene.to_alipay_dict()
            else:
                params['business_scene'] = self.business_scene
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncPidUnwriteoffQueryModel()
        if 'business_scene' in d:
            o.business_scene = d['business_scene']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataIotdataBaiCargocountQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataIotdataBaiCargocountQueryResponse, self).__init__()
        self._storage_detail = None
        self._storage_num = None

    @property
    def storage_detail(self):
        return self._storage_detail

    @storage_detail.setter
    def storage_detail(self, value):
        self._storage_detail = value
    @property
    def storage_num(self):
        return self._storage_num

    @storage_num.setter
    def storage_num(self, value):
        self._storage_num = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataIotdataBaiCargocountQueryResponse, self).parse_response_content(response_content)
        if 'storage_detail' in response:
            self.storage_detail = response['storage_detail']
        if 'storage_num' in response:
            self.storage_num = response['storage_num']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FraudData(object):

    def __init__(self):
        self._device_identifier = None
        self._user_identifier = None

    @property
    def device_identifier(self):
        return self._device_identifier

    @device_identifier.setter
    def device_identifier(self, value):
        self._device_identifier = value
    @property
    def user_identifier(self):
        return self._user_identifier

    @user_identifier.setter
    def user_identifier(self, value):
        self._user_identifier = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_identifier:
            if hasattr(self.device_identifier, 'to_alipay_dict'):
                params['device_identifier'] = self.device_identifier.to_alipay_dict()
            else:
                params['device_identifier'] = self.device_identifier
        if self.user_identifier:
            if hasattr(self.user_identifier, 'to_alipay_dict'):
                params['user_identifier'] = self.user_identifier.to_alipay_dict()
            else:
                params['user_identifier'] = self.user_identifier
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FraudData()
        if 'device_identifier' in d:
            o.device_identifier = d['device_identifier']
        if 'user_identifier' in d:
            o.user_identifier = d['user_identifier']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QueryResult(object):

    def __init__(self):
        self._background_url = None
        self._brand_id = None
        self._brand_name = None
        self._cc = None
        self._company_id = None
        self._company_name = None
        self._engine = None
        self._logo_url = None
        self._model_id = None
        self._model_name = None
        self._prod_year = None
        self._serie_group = None
        self._serie_id = None
        self._serie_name = None
        self._serie_photo = None
        self._style = None

    @property
    def background_url(self):
        return self._background_url

    @background_url.setter
    def background_url(self, value):
        self._background_url = value
    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def cc(self):
        return self._cc

    @cc.setter
    def cc(self, value):
        self._cc = value
    @property
    def company_id(self):
        return self._company_id

    @company_id.setter
    def company_id(self, value):
        self._company_id = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def engine(self):
        return self._engine

    @engine.setter
    def engine(self, value):
        self._engine = value
    @property
    def logo_url(self):
        return self._logo_url

    @logo_url.setter
    def logo_url(self, value):
        self._logo_url = value
    @property
    def model_id(self):
        return self._model_id

    @model_id.setter
    def model_id(self, value):
        self._model_id = value
    @property
    def model_name(self):
        return self._model_name

    @model_name.setter
    def model_name(self, value):
        self._model_name = value
    @property
    def prod_year(self):
        return self._prod_year

    @prod_year.setter
    def prod_year(self, value):
        self._prod_year = value
    @property
    def serie_group(self):
        return self._serie_group

    @serie_group.setter
    def serie_group(self, value):
        self._serie_group = value
    @property
    def serie_id(self):
        return self._serie_id

    @serie_id.setter
    def serie_id(self, value):
        self._serie_id = value
    @property
    def serie_name(self):
        return self._serie_name

    @serie_name.setter
    def serie_name(self, value):
        self._serie_name = value
    @property
    def serie_photo(self):
        return self._serie_photo

    @serie_photo.setter
    def serie_photo(self, value):
        self._serie_photo = value
    @property
    def style(self):
        return self._style

    @style.setter
    def style(self, value):
        self._style = value


    def to_alipay_dict(self):
        params = dict()
        if self.background_url:
            if hasattr(self.background_url, 'to_alipay_dict'):
                params['background_url'] = self.background_url.to_alipay_dict()
            else:
                params['background_url'] = self.background_url
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.cc:
            if hasattr(self.cc, 'to_alipay_dict'):
                params['cc'] = self.cc.to_alipay_dict()
            else:
                params['cc'] = self.cc
        if self.company_id:
            if hasattr(self.company_id, 'to_alipay_dict'):
                params['company_id'] = self.company_id.to_alipay_dict()
            else:
                params['company_id'] = self.company_id
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.engine:
            if hasattr(self.engine, 'to_alipay_dict'):
                params['engine'] = self.engine.to_alipay_dict()
            else:
                params['engine'] = self.engine
        if self.logo_url:
            if hasattr(self.logo_url, 'to_alipay_dict'):
                params['logo_url'] = self.logo_url.to_alipay_dict()
            else:
                params['logo_url'] = self.logo_url
        if self.model_id:
            if hasattr(self.model_id, 'to_alipay_dict'):
                params['model_id'] = self.model_id.to_alipay_dict()
            else:
                params['model_id'] = self.model_id
        if self.model_name:
            if hasattr(self.model_name, 'to_alipay_dict'):
                params['model_name'] = self.model_name.to_alipay_dict()
            else:
                params['model_name'] = self.model_name
        if self.prod_year:
            if hasattr(self.prod_year, 'to_alipay_dict'):
                params['prod_year'] = self.prod_year.to_alipay_dict()
            else:
                params['prod_year'] = self.prod_year
        if self.serie_group:
            if hasattr(self.serie_group, 'to_alipay_dict'):
                params['serie_group'] = self.serie_group.to_alipay_dict()
            else:
                params['serie_group'] = self.serie_group
        if self.serie_id:
            if hasattr(self.serie_id, 'to_alipay_dict'):
                params['serie_id'] = self.serie_id.to_alipay_dict()
            else:
                params['serie_id'] = self.serie_id
        if self.serie_name:
            if hasattr(self.serie_name, 'to_alipay_dict'):
                params['serie_name'] = self.serie_name.to_alipay_dict()
            else:
                params['serie_name'] = self.serie_name
        if self.serie_photo:
            if hasattr(self.serie_photo, 'to_alipay_dict'):
                params['serie_photo'] = self.serie_photo.to_alipay_dict()
            else:
                params['serie_photo'] = self.serie_photo
        if self.style:
            if hasattr(self.style, 'to_alipay_dict'):
                params['style'] = self.style.to_alipay_dict()
            else:
                params['style'] = self.style
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QueryResult()
        if 'background_url' in d:
            o.background_url = d['background_url']
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'cc' in d:
            o.cc = d['cc']
        if 'company_id' in d:
            o.company_id = d['company_id']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'engine' in d:
            o.engine = d['engine']
        if 'logo_url' in d:
            o.logo_url = d['logo_url']
        if 'model_id' in d:
            o.model_id = d['model_id']
        if 'model_name' in d:
            o.model_name = d['model_name']
        if 'prod_year' in d:
            o.prod_year = d['prod_year']
        if 'serie_group' in d:
            o.serie_group = d['serie_group']
        if 'serie_id' in d:
            o.serie_id = d['serie_id']
        if 'serie_name' in d:
            o.serie_name = d['serie_name']
        if 'serie_photo' in d:
            o.serie_photo = d['serie_photo']
        if 'style' in d:
            o.style = d['style']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdSignatureFileUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdSignatureFileUploadResponse, self).__init__()
        self._oss_file_id = None

    @property
    def oss_file_id(self):
        return self._oss_file_id

    @oss_file_id.setter
    def oss_file_id(self, value):
        self._oss_file_id = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdSignatureFileUploadResponse, self).parse_response_content(response_content)
        if 'oss_file_id' in response:
            self.oss_file_id = response['oss_file_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppCommunityRoomCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppCommunityRoomCreateResponse, self).__init__()
        self._community_room_url = None
        self._room_id = None

    @property
    def community_room_url(self):
        return self._community_room_url

    @community_room_url.setter
    def community_room_url(self, value):
        self._community_room_url = value
    @property
    def room_id(self):
        return self._room_id

    @room_id.setter
    def room_id(self, value):
        self._room_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppCommunityRoomCreateResponse, self).parse_response_content(response_content)
        if 'community_room_url' in response:
            self.community_room_url = response['community_room_url']
        if 'room_id' in response:
            self.room_id = response['room_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseIdpdrivenSendModel(object):

    def __init__(self):
        self._asset_id = None
        self._data = None
        self._data_time = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def data_time(self):
        return self._data_time

    @data_time.setter
    def data_time(self, value):
        self._data_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_id:
            if hasattr(self.asset_id, 'to_alipay_dict'):
                params['asset_id'] = self.asset_id.to_alipay_dict()
            else:
                params['asset_id'] = self.asset_id
        if self.data:
            if hasattr(self.data, 'to_alipay_dict'):
                params['data'] = self.data.to_alipay_dict()
            else:
                params['data'] = self.data
        if self.data_time:
            if hasattr(self.data_time, 'to_alipay_dict'):
                params['data_time'] = self.data_time.to_alipay_dict()
            else:
                params['data_time'] = self.data_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseIdpdrivenSendModel()
        if 'asset_id' in d:
            o.asset_id = d['asset_id']
        if 'data' in d:
            o.data = d['data']
        if 'data_time' in d:
            o.data_time = d['data_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TestCaseDomain import TestCaseDomain


class KoubeiQualityTestShieldTestcaseQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiQualityTestShieldTestcaseQueryResponse, self).__init__()
        self._case_list = None
        self._ext_infos = None

    @property
    def case_list(self):
        return self._case_list

    @case_list.setter
    def case_list(self, value):
        if isinstance(value, list):
            self._case_list = list()
            for i in value:
                if isinstance(i, TestCaseDomain):
                    self._case_list.append(i)
                else:
                    self._case_list.append(TestCaseDomain.from_alipay_dict(i))
    @property
    def ext_infos(self):
        return self._ext_infos

    @ext_infos.setter
    def ext_infos(self, value):
        self._ext_infos = value

    def parse_response_content(self, response_content):
        response = super(KoubeiQualityTestShieldTestcaseQueryResponse, self).parse_response_content(response_content)
        if 'case_list' in response:
            self.case_list = response['case_list']
        if 'ext_infos' in response:
            self.ext_infos = response['ext_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneInsserviceprodItemQueryModel(object):

    def __init__(self):
        self._page = None
        self._page_size = None

    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value


    def to_alipay_dict(self):
        params = dict()
        if self.page:
            if hasattr(self.page, 'to_alipay_dict'):
                params['page'] = self.page.to_alipay_dict()
            else:
                params['page'] = self.page
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneInsserviceprodItemQueryModel()
        if 'page' in d:
            o.page = d['page']
        if 'page_size' in d:
            o.page_size = d['page_size']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Participant import Participant
from alipay.aop.api.domain.Participant import Participant


class AlipayFundTransPagePayModel(object):

    def __init__(self):
        self._biz_scene = None
        self._business_params = None
        self._order_id = None
        self._order_title = None
        self._out_biz_no = None
        self._passback_params = None
        self._payee_info = None
        self._payer_info = None
        self._product_code = None
        self._refund_time_expire = None
        self._remark = None
        self._time_expire = None
        self._trans_amount = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def business_params(self):
        return self._business_params

    @business_params.setter
    def business_params(self, value):
        self._business_params = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def passback_params(self):
        return self._passback_params

    @passback_params.setter
    def passback_params(self, value):
        self._passback_params = value
    @property
    def payee_info(self):
        return self._payee_info

    @payee_info.setter
    def payee_info(self, value):
        if isinstance(value, Participant):
            self._payee_info = value
        else:
            self._payee_info = Participant.from_alipay_dict(value)
    @property
    def payer_info(self):
        return self._payer_info

    @payer_info.setter
    def payer_info(self, value):
        if isinstance(value, Participant):
            self._payer_info = value
        else:
            self._payer_info = Participant.from_alipay_dict(value)
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def refund_time_expire(self):
        return self._refund_time_expire

    @refund_time_expire.setter
    def refund_time_expire(self, value):
        self._refund_time_expire = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def time_expire(self):
        return self._time_expire

    @time_expire.setter
    def time_expire(self, value):
        self._time_expire = value
    @property
    def trans_amount(self):
        return self._trans_amount

    @trans_amount.setter
    def trans_amount(self, value):
        self._trans_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.business_params:
            if hasattr(self.business_params, 'to_alipay_dict'):
                params['business_params'] = self.business_params.to_alipay_dict()
            else:
                params['business_params'] = self.business_params
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_title:
            if hasattr(self.order_title, 'to_alipay_dict'):
                params['order_title'] = self.order_title.to_alipay_dict()
            else:
                params['order_title'] = self.order_title
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.passback_params:
            if hasattr(self.passback_params, 'to_alipay_dict'):
                params['passback_params'] = self.passback_params.to_alipay_dict()
            else:
                params['passback_params'] = self.passback_params
        if self.payee_info:
            if hasattr(self.payee_info, 'to_alipay_dict'):
                params['payee_info'] = self.payee_info.to_alipay_dict()
            else:
                params['payee_info'] = self.payee_info
        if self.payer_info:
            if hasattr(self.payer_info, 'to_alipay_dict'):
                params['payer_info'] = self.payer_info.to_alipay_dict()
            else:
                params['payer_info'] = self.payer_info
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.refund_time_expire:
            if hasattr(self.refund_time_expire, 'to_alipay_dict'):
                params['refund_time_expire'] = self.refund_time_expire.to_alipay_dict()
            else:
                params['refund_time_expire'] = self.refund_time_expire
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.time_expire:
            if hasattr(self.time_expire, 'to_alipay_dict'):
                params['time_expire'] = self.time_expire.to_alipay_dict()
            else:
                params['time_expire'] = self.time_expire
        if self.trans_amount:
            if hasattr(self.trans_amount, 'to_alipay_dict'):
                params['trans_amount'] = self.trans_amount.to_alipay_dict()
            else:
                params['trans_amount'] = self.trans_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransPagePayModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'business_params' in d:
            o.business_params = d['business_params']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_title' in d:
            o.order_title = d['order_title']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'passback_params' in d:
            o.passback_params = d['passback_params']
        if 'payee_info' in d:
            o.payee_info = d['payee_info']
        if 'payer_info' in d:
            o.payer_info = d['payer_info']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'refund_time_expire' in d:
            o.refund_time_expire = d['refund_time_expire']
        if 'remark' in d:
            o.remark = d['remark']
        if 'time_expire' in d:
            o.time_expire = d['time_expire']
        if 'trans_amount' in d:
            o.trans_amount = d['trans_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringTablecodeQueryModel(object):

    def __init__(self):
        self._url_context = None

    @property
    def url_context(self):
        return self._url_context

    @url_context.setter
    def url_context(self, value):
        self._url_context = value


    def to_alipay_dict(self):
        params = dict()
        if self.url_context:
            if hasattr(self.url_context, 'to_alipay_dict'):
                params['url_context'] = self.url_context.to_alipay_dict()
            else:
                params['url_context'] = self.url_context
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringTablecodeQueryModel()
        if 'url_context' in d:
            o.url_context = d['url_context']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.VoucherTemplate import VoucherTemplate


class AlipayMarketingCampaignSelfActivityQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignSelfActivityQueryResponse, self).__init__()
        self._activity_end_time = None
        self._activity_name = None
        self._activity_start_time = None
        self._activity_status = None
        self._merchant_logo = None
        self._merchant_name = None
        self._voucher_template_list = None

    @property
    def activity_end_time(self):
        return self._activity_end_time

    @activity_end_time.setter
    def activity_end_time(self, value):
        self._activity_end_time = value
    @property
    def activity_name(self):
        return self._activity_name

    @activity_name.setter
    def activity_name(self, value):
        self._activity_name = value
    @property
    def activity_start_time(self):
        return self._activity_start_time

    @activity_start_time.setter
    def activity_start_time(self, value):
        self._activity_start_time = value
    @property
    def activity_status(self):
        return self._activity_status

    @activity_status.setter
    def activity_status(self, value):
        self._activity_status = value
    @property
    def merchant_logo(self):
        return self._merchant_logo

    @merchant_logo.setter
    def merchant_logo(self, value):
        self._merchant_logo = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def voucher_template_list(self):
        return self._voucher_template_list

    @voucher_template_list.setter
    def voucher_template_list(self, value):
        if isinstance(value, list):
            self._voucher_template_list = list()
            for i in value:
                if isinstance(i, VoucherTemplate):
                    self._voucher_template_list.append(i)
                else:
                    self._voucher_template_list.append(VoucherTemplate.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignSelfActivityQueryResponse, self).parse_response_content(response_content)
        if 'activity_end_time' in response:
            self.activity_end_time = response['activity_end_time']
        if 'activity_name' in response:
            self.activity_name = response['activity_name']
        if 'activity_start_time' in response:
            self.activity_start_time = response['activity_start_time']
        if 'activity_status' in response:
            self.activity_status = response['activity_status']
        if 'merchant_logo' in response:
            self.merchant_logo = response['merchant_logo']
        if 'merchant_name' in response:
            self.merchant_name = response['merchant_name']
        if 'voucher_template_list' in response:
            self.voucher_template_list = response['voucher_template_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOfflineProviderEquipmentAuthRemoveModel(object):

    def __init__(self):
        self._device_id = None
        self._device_type = None
        self._ext_info = None
        self._merchant_pid = None
        self._operator = None
        self._operator_id = None

    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def device_type(self):
        return self._device_type

    @device_type.setter
    def device_type(self, value):
        self._device_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.device_type:
            if hasattr(self.device_type, 'to_alipay_dict'):
                params['device_type'] = self.device_type.to_alipay_dict()
            else:
                params['device_type'] = self.device_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOfflineProviderEquipmentAuthRemoveModel()
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'device_type' in d:
            o.device_type = d['device_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'operator' in d:
            o.operator = d['operator']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditSceneprodCommonQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSceneprodCommonQueryResponse, self).__init__()
        self._info = None
        self._msg = None
        self._retry = None
        self._trace_id = None

    @property
    def info(self):
        return self._info

    @info.setter
    def info(self, value):
        self._info = value
    @property
    def msg(self):
        return self._msg

    @msg.setter
    def msg(self, value):
        self._msg = value
    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSceneprodCommonQueryResponse, self).parse_response_content(response_content)
        if 'info' in response:
            self.info = response['info']
        if 'msg' in response:
            self.msg = response['msg']
        if 'retry' in response:
            self.retry = response['retry']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateCompetitionResultNotifyModel(object):

    def __init__(self):
        self._result_code = None
        self._result_msg = None
        self._source_id = None

    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.result_code:
            if hasattr(self.result_code, 'to_alipay_dict'):
                params['result_code'] = self.result_code.to_alipay_dict()
            else:
                params['result_code'] = self.result_code
        if self.result_msg:
            if hasattr(self.result_msg, 'to_alipay_dict'):
                params['result_msg'] = self.result_msg.to_alipay_dict()
            else:
                params['result_msg'] = self.result_msg
        if self.source_id:
            if hasattr(self.source_id, 'to_alipay_dict'):
                params['source_id'] = self.source_id.to_alipay_dict()
            else:
                params['source_id'] = self.source_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateCompetitionResultNotifyModel()
        if 'result_code' in d:
            o.result_code = d['result_code']
        if 'result_msg' in d:
            o.result_msg = d['result_msg']
        if 'source_id' in d:
            o.source_id = d['source_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneSellerDataQueryModel(object):

    def __init__(self):
        self._dx_name = None
        self._extra_data = None
        self._prod_no = None
        self._sp_no = None

    @property
    def dx_name(self):
        return self._dx_name

    @dx_name.setter
    def dx_name(self, value):
        self._dx_name = value
    @property
    def extra_data(self):
        return self._extra_data

    @extra_data.setter
    def extra_data(self, value):
        self._extra_data = value
    @property
    def prod_no(self):
        return self._prod_no

    @prod_no.setter
    def prod_no(self, value):
        self._prod_no = value
    @property
    def sp_no(self):
        return self._sp_no

    @sp_no.setter
    def sp_no(self, value):
        self._sp_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.dx_name:
            if hasattr(self.dx_name, 'to_alipay_dict'):
                params['dx_name'] = self.dx_name.to_alipay_dict()
            else:
                params['dx_name'] = self.dx_name
        if self.extra_data:
            if hasattr(self.extra_data, 'to_alipay_dict'):
                params['extra_data'] = self.extra_data.to_alipay_dict()
            else:
                params['extra_data'] = self.extra_data
        if self.prod_no:
            if hasattr(self.prod_no, 'to_alipay_dict'):
                params['prod_no'] = self.prod_no.to_alipay_dict()
            else:
                params['prod_no'] = self.prod_no
        if self.sp_no:
            if hasattr(self.sp_no, 'to_alipay_dict'):
                params['sp_no'] = self.sp_no.to_alipay_dict()
            else:
                params['sp_no'] = self.sp_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneSellerDataQueryModel()
        if 'dx_name' in d:
            o.dx_name = d['dx_name']
        if 'extra_data' in d:
            o.extra_data = d['extra_data']
        if 'prod_no' in d:
            o.prod_no = d['prod_no']
        if 'sp_no' in d:
            o.sp_no = d['sp_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEducateSchoolcodeTokenCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateSchoolcodeTokenCreateResponse, self).__init__()
        self._school_code_token = None

    @property
    def school_code_token(self):
        return self._school_code_token

    @school_code_token.setter
    def school_code_token(self, value):
        self._school_code_token = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateSchoolcodeTokenCreateResponse, self).parse_response_content(response_content)
        if 'school_code_token' in response:
            self.school_code_token = response['school_code_token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingCampaignItemMerchantactivityQueryModel(object):

    def __init__(self):
        self._activity_id = None
        self._external_unique_id = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def external_unique_id(self):
        return self._external_unique_id

    @external_unique_id.setter
    def external_unique_id(self, value):
        self._external_unique_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.external_unique_id:
            if hasattr(self.external_unique_id, 'to_alipay_dict'):
                params['external_unique_id'] = self.external_unique_id.to_alipay_dict()
            else:
                params['external_unique_id'] = self.external_unique_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignItemMerchantactivityQueryModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'external_unique_id' in d:
            o.external_unique_id = d['external_unique_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditLoantradePartnerPaymentQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoantradePartnerPaymentQueryResponse, self).__init__()
        self._content = None
        self._finish_time = None
        self._in_apply_no = None
        self._status = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def finish_time(self):
        return self._finish_time

    @finish_time.setter
    def finish_time(self, value):
        self._finish_time = value
    @property
    def in_apply_no(self):
        return self._in_apply_no

    @in_apply_no.setter
    def in_apply_no(self, value):
        self._in_apply_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoantradePartnerPaymentQueryResponse, self).parse_response_content(response_content)
        if 'content' in response:
            self.content = response['content']
        if 'finish_time' in response:
            self.finish_time = response['finish_time']
        if 'in_apply_no' in response:
            self.in_apply_no = response['in_apply_no']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderShop(object):

    def __init__(self):
        self._legal_person_identity_card = None
        self._shop_address = None
        self._shop_city = None
        self._shop_district = None
        self._shop_industry = None
        self._shop_latitude = None
        self._shop_licence_photo = None
        self._shop_linkman_mobile = None
        self._shop_linkman_name = None
        self._shop_longitude = None
        self._shop_name = None
        self._shop_open_time = None
        self._shop_province = None

    @property
    def legal_person_identity_card(self):
        return self._legal_person_identity_card

    @legal_person_identity_card.setter
    def legal_person_identity_card(self, value):
        self._legal_person_identity_card = value
    @property
    def shop_address(self):
        return self._shop_address

    @shop_address.setter
    def shop_address(self, value):
        self._shop_address = value
    @property
    def shop_city(self):
        return self._shop_city

    @shop_city.setter
    def shop_city(self, value):
        self._shop_city = value
    @property
    def shop_district(self):
        return self._shop_district

    @shop_district.setter
    def shop_district(self, value):
        self._shop_district = value
    @property
    def shop_industry(self):
        return self._shop_industry

    @shop_industry.setter
    def shop_industry(self, value):
        self._shop_industry = value
    @property
    def shop_latitude(self):
        return self._shop_latitude

    @shop_latitude.setter
    def shop_latitude(self, value):
        self._shop_latitude = value
    @property
    def shop_licence_photo(self):
        return self._shop_licence_photo

    @shop_licence_photo.setter
    def shop_licence_photo(self, value):
        self._shop_licence_photo = value
    @property
    def shop_linkman_mobile(self):
        return self._shop_linkman_mobile

    @shop_linkman_mobile.setter
    def shop_linkman_mobile(self, value):
        self._shop_linkman_mobile = value
    @property
    def shop_linkman_name(self):
        return self._shop_linkman_name

    @shop_linkman_name.setter
    def shop_linkman_name(self, value):
        self._shop_linkman_name = value
    @property
    def shop_longitude(self):
        return self._shop_longitude

    @shop_longitude.setter
    def shop_longitude(self, value):
        self._shop_longitude = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_open_time(self):
        return self._shop_open_time

    @shop_open_time.setter
    def shop_open_time(self, value):
        self._shop_open_time = value
    @property
    def shop_province(self):
        return self._shop_province

    @shop_province.setter
    def shop_province(self, value):
        self._shop_province = value


    def to_alipay_dict(self):
        params = dict()
        if self.legal_person_identity_card:
            if hasattr(self.legal_person_identity_card, 'to_alipay_dict'):
                params['legal_person_identity_card'] = self.legal_person_identity_card.to_alipay_dict()
            else:
                params['legal_person_identity_card'] = self.legal_person_identity_card
        if self.shop_address:
            if hasattr(self.shop_address, 'to_alipay_dict'):
                params['shop_address'] = self.shop_address.to_alipay_dict()
            else:
                params['shop_address'] = self.shop_address
        if self.shop_city:
            if hasattr(self.shop_city, 'to_alipay_dict'):
                params['shop_city'] = self.shop_city.to_alipay_dict()
            else:
                params['shop_city'] = self.shop_city
        if self.shop_district:
            if hasattr(self.shop_district, 'to_alipay_dict'):
                params['shop_district'] = self.shop_district.to_alipay_dict()
            else:
                params['shop_district'] = self.shop_district
        if self.shop_industry:
            if hasattr(self.shop_industry, 'to_alipay_dict'):
                params['shop_industry'] = self.shop_industry.to_alipay_dict()
            else:
                params['shop_industry'] = self.shop_industry
        if self.shop_latitude:
            if hasattr(self.shop_latitude, 'to_alipay_dict'):
                params['shop_latitude'] = self.shop_latitude.to_alipay_dict()
            else:
                params['shop_latitude'] = self.shop_latitude
        if self.shop_licence_photo:
            if hasattr(self.shop_licence_photo, 'to_alipay_dict'):
                params['shop_licence_photo'] = self.shop_licence_photo.to_alipay_dict()
            else:
                params['shop_licence_photo'] = self.shop_licence_photo
        if self.shop_linkman_mobile:
            if hasattr(self.shop_linkman_mobile, 'to_alipay_dict'):
                params['shop_linkman_mobile'] = self.shop_linkman_mobile.to_alipay_dict()
            else:
                params['shop_linkman_mobile'] = self.shop_linkman_mobile
        if self.shop_linkman_name:
            if hasattr(self.shop_linkman_name, 'to_alipay_dict'):
                params['shop_linkman_name'] = self.shop_linkman_name.to_alipay_dict()
            else:
                params['shop_linkman_name'] = self.shop_linkman_name
        if self.shop_longitude:
            if hasattr(self.shop_longitude, 'to_alipay_dict'):
                params['shop_longitude'] = self.shop_longitude.to_alipay_dict()
            else:
                params['shop_longitude'] = self.shop_longitude
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_open_time:
            if hasattr(self.shop_open_time, 'to_alipay_dict'):
                params['shop_open_time'] = self.shop_open_time.to_alipay_dict()
            else:
                params['shop_open_time'] = self.shop_open_time
        if self.shop_province:
            if hasattr(self.shop_province, 'to_alipay_dict'):
                params['shop_province'] = self.shop_province.to_alipay_dict()
            else:
                params['shop_province'] = self.shop_province
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderShop()
        if 'legal_person_identity_card' in d:
            o.legal_person_identity_card = d['legal_person_identity_card']
        if 'shop_address' in d:
            o.shop_address = d['shop_address']
        if 'shop_city' in d:
            o.shop_city = d['shop_city']
        if 'shop_district' in d:
            o.shop_district = d['shop_district']
        if 'shop_industry' in d:
            o.shop_industry = d['shop_industry']
        if 'shop_latitude' in d:
            o.shop_latitude = d['shop_latitude']
        if 'shop_licence_photo' in d:
            o.shop_licence_photo = d['shop_licence_photo']
        if 'shop_linkman_mobile' in d:
            o.shop_linkman_mobile = d['shop_linkman_mobile']
        if 'shop_linkman_name' in d:
            o.shop_linkman_name = d['shop_linkman_name']
        if 'shop_longitude' in d:
            o.shop_longitude = d['shop_longitude']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_open_time' in d:
            o.shop_open_time = d['shop_open_time']
        if 'shop_province' in d:
            o.shop_province = d['shop_province']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppAuthsubsAddResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppAuthsubsAddResponse, self).__init__()
        self._auth_code = None
        self._invalid_date = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def invalid_date(self):
        return self._invalid_date

    @invalid_date.setter
    def invalid_date(self, value):
        self._invalid_date = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppAuthsubsAddResponse, self).parse_response_content(response_content)
        if 'auth_code' in response:
            self.auth_code = response['auth_code']
        if 'invalid_date' in response:
            self.invalid_date = response['invalid_date']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InteligentBudgetInfo(object):

    def __init__(self):
        self._budget_total = None
        self._budget_type = None

    @property
    def budget_total(self):
        return self._budget_total

    @budget_total.setter
    def budget_total(self, value):
        self._budget_total = value
    @property
    def budget_type(self):
        return self._budget_type

    @budget_type.setter
    def budget_type(self, value):
        self._budget_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.budget_total:
            if hasattr(self.budget_total, 'to_alipay_dict'):
                params['budget_total'] = self.budget_total.to_alipay_dict()
            else:
                params['budget_total'] = self.budget_total
        if self.budget_type:
            if hasattr(self.budget_type, 'to_alipay_dict'):
                params['budget_type'] = self.budget_type.to_alipay_dict()
            else:
                params['budget_type'] = self.budget_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InteligentBudgetInfo()
        if 'budget_total' in d:
            o.budget_total = d['budget_total']
        if 'budget_type' in d:
            o.budget_type = d['budget_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LendingDataList(object):

    def __init__(self):
        self._curr_fba_inv_value = None
        self._currency = None
        self._disbursements_eight_m = None
        self._disbursements_eight_q = None
        self._disbursements_eleven_m = None
        self._disbursements_five_m = None
        self._disbursements_five_q = None
        self._disbursements_five_w = None
        self._disbursements_four_m = None
        self._disbursements_four_q = None
        self._disbursements_four_w = None
        self._disbursements_nine_m = None
        self._disbursements_one_m = None
        self._disbursements_one_q = None
        self._disbursements_one_w = None
        self._disbursements_one_y = None
        self._disbursements_seven_m = None
        self._disbursements_seven_q = None
        self._disbursements_six_m = None
        self._disbursements_six_q = None
        self._disbursements_six_w = None
        self._disbursements_ten_m = None
        self._disbursements_three_m = None
        self._disbursements_three_q = None
        self._disbursements_three_w = None
        self._disbursements_twelve_m = None
        self._disbursements_two_m = None
        self._disbursements_two_q = None
        self._disbursements_two_w = None
        self._disbursements_two_y = None
        self._marketplace_country = None
        self._offer_id = None
        self._primary_category_last_three_month_sales_value = None
        self._primary_product_category = None
        self._report_card_data_date = None
        self._sales_eight_m = None
        self._sales_eight_q = None
        self._sales_eleven_m = None
        self._sales_five_m = None
        self._sales_five_q = None
        self._sales_five_w = None
        self._sales_four_m = None
        self._sales_four_q = None
        self._sales_four_w = None
        self._sales_nine_m = None
        self._sales_one_m = None
        self._sales_one_q = None
        self._sales_one_w = None
        self._sales_one_y = None
        self._sales_seven_m = None
        self._sales_seven_q = None
        self._sales_six_m = None
        self._sales_six_q = None
        self._sales_six_w = None
        self._sales_stability_score = None
        self._sales_ten_m = None
        self._sales_three_m = None
        self._sales_three_q = None
        self._sales_three_w = None
        self._sales_twelve_m = None
        self._sales_two_m = None
        self._sales_two_q = None
        self._sales_two_w = None
        self._sales_two_y = None
        self._seller_status = None
        self._t_thirteen_wk_fba = None
        self._t_three_m_fba_inv_value = None
        self._tenure = None
        self._ttm_cancellations = None
        self._ttm_enforcements = None
        self._ttm_feedback = None
        self._ttm_late_shipments = None
        self._ttm_neg_feedback = None
        self._ttm_order_defects = None
        self._ttm_orders = None
        self._ttm_returns = None

    @property
    def curr_fba_inv_value(self):
        return self._curr_fba_inv_value

    @curr_fba_inv_value.setter
    def curr_fba_inv_value(self, value):
        self._curr_fba_inv_value = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def disbursements_eight_m(self):
        return self._disbursements_eight_m

    @disbursements_eight_m.setter
    def disbursements_eight_m(self, value):
        self._disbursements_eight_m = value
    @property
    def disbursements_eight_q(self):
        return self._disbursements_eight_q

    @disbursements_eight_q.setter
    def disbursements_eight_q(self, value):
        self._disbursements_eight_q = value
    @property
    def disbursements_eleven_m(self):
        return self._disbursements_eleven_m

    @disbursements_eleven_m.setter
    def disbursements_eleven_m(self, value):
        self._disbursements_eleven_m = value
    @property
    def disbursements_five_m(self):
        return self._disbursements_five_m

    @disbursements_five_m.setter
    def disbursements_five_m(self, value):
        self._disbursements_five_m = value
    @property
    def disbursements_five_q(self):
        return self._disbursements_five_q

    @disbursements_five_q.setter
    def disbursements_five_q(self, value):
        self._disbursements_five_q = value
    @property
    def disbursements_five_w(self):
        return self._disbursements_five_w

    @disbursements_five_w.setter
    def disbursements_five_w(self, value):
        self._disbursements_five_w = value
    @property
    def disbursements_four_m(self):
        return self._disbursements_four_m

    @disbursements_four_m.setter
    def disbursements_four_m(self, value):
        self._disbursements_four_m = value
    @property
    def disbursements_four_q(self):
        return self._disbursements_four_q

    @disbursements_four_q.setter
    def disbursements_four_q(self, value):
        self._disbursements_four_q = value
    @property
    def disbursements_four_w(self):
        return self._disbursements_four_w

    @disbursements_four_w.setter
    def disbursements_four_w(self, value):
        self._disbursements_four_w = value
    @property
    def disbursements_nine_m(self):
        return self._disbursements_nine_m

    @disbursements_nine_m.setter
    def disbursements_nine_m(self, value):
        self._disbursements_nine_m = value
    @property
    def disbursements_one_m(self):
        return self._disbursements_one_m

    @disbursements_one_m.setter
    def disbursements_one_m(self, value):
        self._disbursements_one_m = value
    @property
    def disbursements_one_q(self):
        return self._disbursements_one_q

    @disbursements_one_q.setter
    def disbursements_one_q(self, value):
        self._disbursements_one_q = value
    @property
    def disbursements_one_w(self):
        return self._disbursements_one_w

    @disbursements_one_w.setter
    def disbursements_one_w(self, value):
        self._disbursements_one_w = value
    @property
    def disbursements_one_y(self):
        return self._disbursements_one_y

    @disbursements_one_y.setter
    def disbursements_one_y(self, value):
        self._disbursements_one_y = value
    @property
    def disbursements_seven_m(self):
        return self._disbursements_seven_m

    @disbursements_seven_m.setter
    def disbursements_seven_m(self, value):
        self._disbursements_seven_m = value
    @property
    def disbursements_seven_q(self):
        return self._disbursements_seven_q

    @disbursements_seven_q.setter
    def disbursements_seven_q(self, value):
        self._disbursements_seven_q = value
    @property
    def disbursements_six_m(self):
        return self._disbursements_six_m

    @disbursements_six_m.setter
    def disbursements_six_m(self, value):
        self._disbursements_six_m = value
    @property
    def disbursements_six_q(self):
        return self._disbursements_six_q

    @disbursements_six_q.setter
    def disbursements_six_q(self, value):
        self._disbursements_six_q = value
    @property
    def disbursements_six_w(self):
        return self._disbursements_six_w

    @disbursements_six_w.setter
    def disbursements_six_w(self, value):
        self._disbursements_six_w = value
    @property
    def disbursements_ten_m(self):
        return self._disbursements_ten_m

    @disbursements_ten_m.setter
    def disbursements_ten_m(self, value):
        self._disbursements_ten_m = value
    @property
    def disbursements_three_m(self):
        return self._disbursements_three_m

    @disbursements_three_m.setter
    def disbursements_three_m(self, value):
        self._disbursements_three_m = value
    @property
    def disbursements_three_q(self):
        return self._disbursements_three_q

    @disbursements_three_q.setter
    def disbursements_three_q(self, value):
        self._disbursements_three_q = value
    @property
    def disbursements_three_w(self):
        return self._disbursements_three_w

    @disbursements_three_w.setter
    def disbursements_three_w(self, value):
        self._disbursements_three_w = value
    @property
    def disbursements_twelve_m(self):
        return self._disbursements_twelve_m

    @disbursements_twelve_m.setter
    def disbursements_twelve_m(self, value):
        self._disbursements_twelve_m = value
    @property
    def disbursements_two_m(self):
        return self._disbursements_two_m

    @disbursements_two_m.setter
    def disbursements_two_m(self, value):
        self._disbursements_two_m = value
    @property
    def disbursements_two_q(self):
        return self._disbursements_two_q

    @disbursements_two_q.setter
    def disbursements_two_q(self, value):
        self._disbursements_two_q = value
    @property
    def disbursements_two_w(self):
        return self._disbursements_two_w

    @disbursements_two_w.setter
    def disbursements_two_w(self, value):
        self._disbursements_two_w = value
    @property
    def disbursements_two_y(self):
        return self._disbursements_two_y

    @disbursements_two_y.setter
    def disbursements_two_y(self, value):
        self._disbursements_two_y = value
    @property
    def marketplace_country(self):
        return self._marketplace_country

    @marketplace_country.setter
    def marketplace_country(self, value):
        self._marketplace_country = value
    @property
    def offer_id(self):
        return self._offer_id

    @offer_id.setter
    def offer_id(self, value):
        self._offer_id = value
    @property
    def primary_category_last_three_month_sales_value(self):
        return self._primary_category_last_three_month_sales_value

    @primary_category_last_three_month_sales_value.setter
    def primary_category_last_three_month_sales_value(self, value):
        self._primary_category_last_three_month_sales_value = value
    @property
    def primary_product_category(self):
        return self._primary_product_category

    @primary_product_category.setter
    def primary_product_category(self, value):
        self._primary_product_category = value
    @property
    def report_card_data_date(self):
        return self._report_card_data_date

    @report_card_data_date.setter
    def report_card_data_date(self, value):
        self._report_card_data_date = value
    @property
    def sales_eight_m(self):
        return self._sales_eight_m

    @sales_eight_m.setter
    def sales_eight_m(self, value):
        self._sales_eight_m = value
    @property
    def sales_eight_q(self):
        return self._sales_eight_q

    @sales_eight_q.setter
    def sales_eight_q(self, value):
        self._sales_eight_q = value
    @property
    def sales_eleven_m(self):
        return self._sales_eleven_m

    @sales_eleven_m.setter
    def sales_eleven_m(self, value):
        self._sales_eleven_m = value
    @property
    def sales_five_m(self):
        return self._sales_five_m

    @sales_five_m.setter
    def sales_five_m(self, value):
        self._sales_five_m = value
    @property
    def sales_five_q(self):
        return self._sales_five_q

    @sales_five_q.setter
    def sales_five_q(self, value):
        self._sales_five_q = value
    @property
    def sales_five_w(self):
        return self._sales_five_w

    @sales_five_w.setter
    def sales_five_w(self, value):
        self._sales_five_w = value
    @property
    def sales_four_m(self):
        return self._sales_four_m

    @sales_four_m.setter
    def sales_four_m(self, value):
        self._sales_four_m = value
    @property
    def sales_four_q(self):
        return self._sales_four_q

    @sales_four_q.setter
    def sales_four_q(self, value):
        self._sales_four_q = value
    @property
    def sales_four_w(self):
        return self._sales_four_w

    @sales_four_w.setter
    def sales_four_w(self, value):
        self._sales_four_w = value
    @property
    def sales_nine_m(self):
        return self._sales_nine_m

    @sales_nine_m.setter
    def sales_nine_m(self, value):
        self._sales_nine_m = value
    @property
    def sales_one_m(self):
        return self._sales_one_m

    @sales_one_m.setter
    def sales_one_m(self, value):
        self._sales_one_m = value
    @property
    def sales_one_q(self):
        return self._sales_one_q

    @sales_one_q.setter
    def sales_one_q(self, value):
        self._sales_one_q = value
    @property
    def sales_one_w(self):
        return self._sales_one_w

    @sales_one_w.setter
    def sales_one_w(self, value):
        self._sales_one_w = value
    @property
    def sales_one_y(self):
        return self._sales_one_y

    @sales_one_y.setter
    def sales_one_y(self, value):
        self._sales_one_y = value
    @property
    def sales_seven_m(self):
        return self._sales_seven_m

    @sales_seven_m.setter
    def sales_seven_m(self, value):
        self._sales_seven_m = value
    @property
    def sales_seven_q(self):
        return self._sales_seven_q

    @sales_seven_q.setter
    def sales_seven_q(self, value):
        self._sales_seven_q = value
    @property
    def sales_six_m(self):
        return self._sales_six_m

    @sales_six_m.setter
    def sales_six_m(self, value):
        self._sales_six_m = value
    @property
    def sales_six_q(self):
        return self._sales_six_q

    @sales_six_q.setter
    def sales_six_q(self, value):
        self._sales_six_q = value
    @property
    def sales_six_w(self):
        return self._sales_six_w

    @sales_six_w.setter
    def sales_six_w(self, value):
        self._sales_six_w = value
    @property
    def sales_stability_score(self):
        return self._sales_stability_score

    @sales_stability_score.setter
    def sales_stability_score(self, value):
        self._sales_stability_score = value
    @property
    def sales_ten_m(self):
        return self._sales_ten_m

    @sales_ten_m.setter
    def sales_ten_m(self, value):
        self._sales_ten_m = value
    @property
    def sales_three_m(self):
        return self._sales_three_m

    @sales_three_m.setter
    def sales_three_m(self, value):
        self._sales_three_m = value
    @property
    def sales_three_q(self):
        return self._sales_three_q

    @sales_three_q.setter
    def sales_three_q(self, value):
        self._sales_three_q = value
    @property
    def sales_three_w(self):
        return self._sales_three_w

    @sales_three_w.setter
    def sales_three_w(self, value):
        self._sales_three_w = value
    @property
    def sales_twelve_m(self):
        return self._sales_twelve_m

    @sales_twelve_m.setter
    def sales_twelve_m(self, value):
        self._sales_twelve_m = value
    @property
    def sales_two_m(self):
        return self._sales_two_m

    @sales_two_m.setter
    def sales_two_m(self, value):
        self._sales_two_m = value
    @property
    def sales_two_q(self):
        return self._sales_two_q

    @sales_two_q.setter
    def sales_two_q(self, value):
        self._sales_two_q = value
    @property
    def sales_two_w(self):
        return self._sales_two_w

    @sales_two_w.setter
    def sales_two_w(self, value):
        self._sales_two_w = value
    @property
    def sales_two_y(self):
        return self._sales_two_y

    @sales_two_y.setter
    def sales_two_y(self, value):
        self._sales_two_y = value
    @property
    def seller_status(self):
        return self._seller_status

    @seller_status.setter
    def seller_status(self, value):
        self._seller_status = value
    @property
    def t_thirteen_wk_fba(self):
        return self._t_thirteen_wk_fba

    @t_thirteen_wk_fba.setter
    def t_thirteen_wk_fba(self, value):
        self._t_thirteen_wk_fba = value
    @property
    def t_three_m_fba_inv_value(self):
        return self._t_three_m_fba_inv_value

    @t_three_m_fba_inv_value.setter
    def t_three_m_fba_inv_value(self, value):
        self._t_three_m_fba_inv_value = value
    @property
    def tenure(self):
        return self._tenure

    @tenure.setter
    def tenure(self, value):
        self._tenure = value
    @property
    def ttm_cancellations(self):
        return self._ttm_cancellations

    @ttm_cancellations.setter
    def ttm_cancellations(self, value):
        self._ttm_cancellations = value
    @property
    def ttm_enforcements(self):
        return self._ttm_enforcements

    @ttm_enforcements.setter
    def ttm_enforcements(self, value):
        self._ttm_enforcements = value
    @property
    def ttm_feedback(self):
        return self._ttm_feedback

    @ttm_feedback.setter
    def ttm_feedback(self, value):
        self._ttm_feedback = value
    @property
    def ttm_late_shipments(self):
        return self._ttm_late_shipments

    @ttm_late_shipments.setter
    def ttm_late_shipments(self, value):
        self._ttm_late_shipments = value
    @property
    def ttm_neg_feedback(self):
        return self._ttm_neg_feedback

    @ttm_neg_feedback.setter
    def ttm_neg_feedback(self, value):
        self._ttm_neg_feedback = value
    @property
    def ttm_order_defects(self):
        return self._ttm_order_defects

    @ttm_order_defects.setter
    def ttm_order_defects(self, value):
        self._ttm_order_defects = value
    @property
    def ttm_orders(self):
        return self._ttm_orders

    @ttm_orders.setter
    def ttm_orders(self, value):
        self._ttm_orders = value
    @property
    def ttm_returns(self):
        return self._ttm_returns

    @ttm_returns.setter
    def ttm_returns(self, value):
        self._ttm_returns = value


    def to_alipay_dict(self):
        params = dict()
        if self.curr_fba_inv_value:
            if hasattr(self.curr_fba_inv_value, 'to_alipay_dict'):
                params['curr_fba_inv_value'] = self.curr_fba_inv_value.to_alipay_dict()
            else:
                params['curr_fba_inv_value'] = self.curr_fba_inv_value
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.disbursements_eight_m:
            if hasattr(self.disbursements_eight_m, 'to_alipay_dict'):
                params['disbursements_eight_m'] = self.disbursements_eight_m.to_alipay_dict()
            else:
                params['disbursements_eight_m'] = self.disbursements_eight_m
        if self.disbursements_eight_q:
            if hasattr(self.disbursements_eight_q, 'to_alipay_dict'):
                params['disbursements_eight_q'] = self.disbursements_eight_q.to_alipay_dict()
            else:
                params['disbursements_eight_q'] = self.disbursements_eight_q
        if self.disbursements_eleven_m:
            if hasattr(self.disbursements_eleven_m, 'to_alipay_dict'):
                params['disbursements_eleven_m'] = self.disbursements_eleven_m.to_alipay_dict()
            else:
                params['disbursements_eleven_m'] = self.disbursements_eleven_m
        if self.disbursements_five_m:
            if hasattr(self.disbursements_five_m, 'to_alipay_dict'):
                params['disbursements_five_m'] = self.disbursements_five_m.to_alipay_dict()
            else:
                params['disbursements_five_m'] = self.disbursements_five_m
        if self.disbursements_five_q:
            if hasattr(self.disbursements_five_q, 'to_alipay_dict'):
                params['disbursements_five_q'] = self.disbursements_five_q.to_alipay_dict()
            else:
                params['disbursements_five_q'] = self.disbursements_five_q
        if self.disbursements_five_w:
            if hasattr(self.disbursements_five_w, 'to_alipay_dict'):
                params['disbursements_five_w'] = self.disbursements_five_w.to_alipay_dict()
            else:
                params['disbursements_five_w'] = self.disbursements_five_w
        if self.disbursements_four_m:
            if hasattr(self.disbursements_four_m, 'to_alipay_dict'):
                params['disbursements_four_m'] = self.disbursements_four_m.to_alipay_dict()
            else:
                params['disbursements_four_m'] = self.disbursements_four_m
        if self.disbursements_four_q:
            if hasattr(self.disbursements_four_q, 'to_alipay_dict'):
                params['disbursements_four_q'] = self.disbursements_four_q.to_alipay_dict()
            else:
                params['disbursements_four_q'] = self.disbursements_four_q
        if self.disbursements_four_w:
            if hasattr(self.disbursements_four_w, 'to_alipay_dict'):
                params['disbursements_four_w'] = self.disbursements_four_w.to_alipay_dict()
            else:
                params['disbursements_four_w'] = self.disbursements_four_w
        if self.disbursements_nine_m:
            if hasattr(self.disbursements_nine_m, 'to_alipay_dict'):
                params['disbursements_nine_m'] = self.disbursements_nine_m.to_alipay_dict()
            else:
                params['disbursements_nine_m'] = self.disbursements_nine_m
        if self.disbursements_one_m:
            if hasattr(self.disbursements_one_m, 'to_alipay_dict'):
                params['disbursements_one_m'] = self.disbursements_one_m.to_alipay_dict()
            else:
                params['disbursements_one_m'] = self.disbursements_one_m
        if self.disbursements_one_q:
            if hasattr(self.disbursements_one_q, 'to_alipay_dict'):
                params['disbursements_one_q'] = self.disbursements_one_q.to_alipay_dict()
            else:
                params['disbursements_one_q'] = self.disbursements_one_q
        if self.disbursements_one_w:
            if hasattr(self.disbursements_one_w, 'to_alipay_dict'):
                params['disbursements_one_w'] = self.disbursements_one_w.to_alipay_dict()
            else:
                params['disbursements_one_w'] = self.disbursements_one_w
        if self.disbursements_one_y:
            if hasattr(self.disbursements_one_y, 'to_alipay_dict'):
                params['disbursements_one_y'] = self.disbursements_one_y.to_alipay_dict()
            else:
                params['disbursements_one_y'] = self.disbursements_one_y
        if self.disbursements_seven_m:
            if hasattr(self.disbursements_seven_m, 'to_alipay_dict'):
                params['disbursements_seven_m'] = self.disbursements_seven_m.to_alipay_dict()
            else:
                params['disbursements_seven_m'] = self.disbursements_seven_m
        if self.disbursements_seven_q:
            if hasattr(self.disbursements_seven_q, 'to_alipay_dict'):
                params['disbursements_seven_q'] = self.disbursements_seven_q.to_alipay_dict()
            else:
                params['disbursements_seven_q'] = self.disbursements_seven_q
        if self.disbursements_six_m:
            if hasattr(self.disbursements_six_m, 'to_alipay_dict'):
                params['disbursements_six_m'] = self.disbursements_six_m.to_alipay_dict()
            else:
                params['disbursements_six_m'] = self.disbursements_six_m
        if self.disbursements_six_q:
            if hasattr(self.disbursements_six_q, 'to_alipay_dict'):
                params['disbursements_six_q'] = self.disbursements_six_q.to_alipay_dict()
            else:
                params['disbursements_six_q'] = self.disbursements_six_q
        if self.disbursements_six_w:
            if hasattr(self.disbursements_six_w, 'to_alipay_dict'):
                params['disbursements_six_w'] = self.disbursements_six_w.to_alipay_dict()
            else:
                params['disbursements_six_w'] = self.disbursements_six_w
        if self.disbursements_ten_m:
            if hasattr(self.disbursements_ten_m, 'to_alipay_dict'):
                params['disbursements_ten_m'] = self.disbursements_ten_m.to_alipay_dict()
            else:
                params['disbursements_ten_m'] = self.disbursements_ten_m
        if self.disbursements_three_m:
            if hasattr(self.disbursements_three_m, 'to_alipay_dict'):
                params['disbursements_three_m'] = self.disbursements_three_m.to_alipay_dict()
            else:
                params['disbursements_three_m'] = self.disbursements_three_m
        if self.disbursements_three_q:
            if hasattr(self.disbursements_three_q, 'to_alipay_dict'):
                params['disbursements_three_q'] = self.disbursements_three_q.to_alipay_dict()
            else:
                params['disbursements_three_q'] = self.disbursements_three_q
        if self.disbursements_three_w:
            if hasattr(self.disbursements_three_w, 'to_alipay_dict'):
                params['disbursements_three_w'] = self.disbursements_three_w.to_alipay_dict()
            else:
                params['disbursements_three_w'] = self.disbursements_three_w
        if self.disbursements_twelve_m:
            if hasattr(self.disbursements_twelve_m, 'to_alipay_dict'):
                params['disbursements_twelve_m'] = self.disbursements_twelve_m.to_alipay_dict()
            else:
                params['disbursements_twelve_m'] = self.disbursements_twelve_m
        if self.disbursements_two_m:
            if hasattr(self.disbursements_two_m, 'to_alipay_dict'):
                params['disbursements_two_m'] = self.disbursements_two_m.to_alipay_dict()
            else:
                params['disbursements_two_m'] = self.disbursements_two_m
        if self.disbursements_two_q:
            if hasattr(self.disbursements_two_q, 'to_alipay_dict'):
                params['disbursements_two_q'] = self.disbursements_two_q.to_alipay_dict()
            else:
                params['disbursements_two_q'] = self.disbursements_two_q
        if self.disbursements_two_w:
            if hasattr(self.disbursements_two_w, 'to_alipay_dict'):
                params['disbursements_two_w'] = self.disbursements_two_w.to_alipay_dict()
            else:
                params['disbursements_two_w'] = self.disbursements_two_w
        if self.disbursements_two_y:
            if hasattr(self.disbursements_two_y, 'to_alipay_dict'):
                params['disbursements_two_y'] = self.disbursements_two_y.to_alipay_dict()
            else:
                params['disbursements_two_y'] = self.disbursements_two_y
        if self.marketplace_country:
            if hasattr(self.marketplace_country, 'to_alipay_dict'):
                params['marketplace_country'] = self.marketplace_country.to_alipay_dict()
            else:
                params['marketplace_country'] = self.marketplace_country
        if self.offer_id:
            if hasattr(self.offer_id, 'to_alipay_dict'):
                params['offer_id'] = self.offer_id.to_alipay_dict()
            else:
                params['offer_id'] = self.offer_id
        if self.primary_category_last_three_month_sales_value:
            if hasattr(self.primary_category_last_three_month_sales_value, 'to_alipay_dict'):
                params['primary_category_last_three_month_sales_value'] = self.primary_category_last_three_month_sales_value.to_alipay_dict()
            else:
                params['primary_category_last_three_month_sales_value'] = self.primary_category_last_three_month_sales_value
        if self.primary_product_category:
            if hasattr(self.primary_product_category, 'to_alipay_dict'):
                params['primary_product_category'] = self.primary_product_category.to_alipay_dict()
            else:
                params['primary_product_category'] = self.primary_product_category
        if self.report_card_data_date:
            if hasattr(self.report_card_data_date, 'to_alipay_dict'):
                params['report_card_data_date'] = self.report_card_data_date.to_alipay_dict()
            else:
                params['report_card_data_date'] = self.report_card_data_date
        if self.sales_eight_m:
            if hasattr(self.sales_eight_m, 'to_alipay_dict'):
                params['sales_eight_m'] = self.sales_eight_m.to_alipay_dict()
            else:
                params['sales_eight_m'] = self.sales_eight_m
        if self.sales_eight_q:
            if hasattr(self.sales_eight_q, 'to_alipay_dict'):
                params['sales_eight_q'] = self.sales_eight_q.to_alipay_dict()
            else:
                params['sales_eight_q'] = self.sales_eight_q
        if self.sales_eleven_m:
            if hasattr(self.sales_eleven_m, 'to_alipay_dict'):
                params['sales_eleven_m'] = self.sales_eleven_m.to_alipay_dict()
            else:
                params['sales_eleven_m'] = self.sales_eleven_m
        if self.sales_five_m:
            if hasattr(self.sales_five_m, 'to_alipay_dict'):
                params['sales_five_m'] = self.sales_five_m.to_alipay_dict()
            else:
                params['sales_five_m'] = self.sales_five_m
        if self.sales_five_q:
            if hasattr(self.sales_five_q, 'to_alipay_dict'):
                params['sales_five_q'] = self.sales_five_q.to_alipay_dict()
            else:
                params['sales_five_q'] = self.sales_five_q
        if self.sales_five_w:
            if hasattr(self.sales_five_w, 'to_alipay_dict'):
                params['sales_five_w'] = self.sales_five_w.to_alipay_dict()
            else:
                params['sales_five_w'] = self.sales_five_w
        if self.sales_four_m:
            if hasattr(self.sales_four_m, 'to_alipay_dict'):
                params['sales_four_m'] = self.sales_four_m.to_alipay_dict()
            else:
                params['sales_four_m'] = self.sales_four_m
        if self.sales_four_q:
            if hasattr(self.sales_four_q, 'to_alipay_dict'):
                params['sales_four_q'] = self.sales_four_q.to_alipay_dict()
            else:
                params['sales_four_q'] = self.sales_four_q
        if self.sales_four_w:
            if hasattr(self.sales_four_w, 'to_alipay_dict'):
                params['sales_four_w'] = self.sales_four_w.to_alipay_dict()
            else:
                params['sales_four_w'] = self.sales_four_w
        if self.sales_nine_m:
            if hasattr(self.sales_nine_m, 'to_alipay_dict'):
                params['sales_nine_m'] = self.sales_nine_m.to_alipay_dict()
            else:
                params['sales_nine_m'] = self.sales_nine_m
        if self.sales_one_m:
            if hasattr(self.sales_one_m, 'to_alipay_dict'):
                params['sales_one_m'] = self.sales_one_m.to_alipay_dict()
            else:
                params['sales_one_m'] = self.sales_one_m
        if self.sales_one_q:
            if hasattr(self.sales_one_q, 'to_alipay_dict'):
                params['sales_one_q'] = self.sales_one_q.to_alipay_dict()
            else:
                params['sales_one_q'] = self.sales_one_q
        if self.sales_one_w:
            if hasattr(self.sales_one_w, 'to_alipay_dict'):
                params['sales_one_w'] = self.sales_one_w.to_alipay_dict()
            else:
                params['sales_one_w'] = self.sales_one_w
        if self.sales_one_y:
            if hasattr(self.sales_one_y, 'to_alipay_dict'):
                params['sales_one_y'] = self.sales_one_y.to_alipay_dict()
            else:
                params['sales_one_y'] = self.sales_one_y
        if self.sales_seven_m:
            if hasattr(self.sales_seven_m, 'to_alipay_dict'):
                params['sales_seven_m'] = self.sales_seven_m.to_alipay_dict()
            else:
                params['sales_seven_m'] = self.sales_seven_m
        if self.sales_seven_q:
            if hasattr(self.sales_seven_q, 'to_alipay_dict'):
                params['sales_seven_q'] = self.sales_seven_q.to_alipay_dict()
            else:
                params['sales_seven_q'] = self.sales_seven_q
        if self.sales_six_m:
            if hasattr(self.sales_six_m, 'to_alipay_dict'):
                params['sales_six_m'] = self.sales_six_m.to_alipay_dict()
            else:
                params['sales_six_m'] = self.sales_six_m
        if self.sales_six_q:
            if hasattr(self.sales_six_q, 'to_alipay_dict'):
                params['sales_six_q'] = self.sales_six_q.to_alipay_dict()
            else:
                params['sales_six_q'] = self.sales_six_q
        if self.sales_six_w:
            if hasattr(self.sales_six_w, 'to_alipay_dict'):
                params['sales_six_w'] = self.sales_six_w.to_alipay_dict()
            else:
                params['sales_six_w'] = self.sales_six_w
        if self.sales_stability_score:
            if hasattr(self.sales_stability_score, 'to_alipay_dict'):
                params['sales_stability_score'] = self.sales_stability_score.to_alipay_dict()
            else:
                params['sales_stability_score'] = self.sales_stability_score
        if self.sales_ten_m:
            if hasattr(self.sales_ten_m, 'to_alipay_dict'):
                params['sales_ten_m'] = self.sales_ten_m.to_alipay_dict()
            else:
                params['sales_ten_m'] = self.sales_ten_m
        if self.sales_three_m:
            if hasattr(self.sales_three_m, 'to_alipay_dict'):
                params['sales_three_m'] = self.sales_three_m.to_alipay_dict()
            else:
                params['sales_three_m'] = self.sales_three_m
        if self.sales_three_q:
            if hasattr(self.sales_three_q, 'to_alipay_dict'):
                params['sales_three_q'] = self.sales_three_q.to_alipay_dict()
            else:
                params['sales_three_q'] = self.sales_three_q
        if self.sales_three_w:
            if hasattr(self.sales_three_w, 'to_alipay_dict'):
                params['sales_three_w'] = self.sales_three_w.to_alipay_dict()
            else:
                params['sales_three_w'] = self.sales_three_w
        if self.sales_twelve_m:
            if hasattr(self.sales_twelve_m, 'to_alipay_dict'):
                params['sales_twelve_m'] = self.sales_twelve_m.to_alipay_dict()
            else:
                params['sales_twelve_m'] = self.sales_twelve_m
        if self.sales_two_m:
            if hasattr(self.sales_two_m, 'to_alipay_dict'):
                params['sales_two_m'] = self.sales_two_m.to_alipay_dict()
            else:
                params['sales_two_m'] = self.sales_two_m
        if self.sales_two_q:
            if hasattr(self.sales_two_q, 'to_alipay_dict'):
                params['sales_two_q'] = self.sales_two_q.to_alipay_dict()
            else:
                params['sales_two_q'] = self.sales_two_q
        if self.sales_two_w:
            if hasattr(self.sales_two_w, 'to_alipay_dict'):
                params['sales_two_w'] = self.sales_two_w.to_alipay_dict()
            else:
                params['sales_two_w'] = self.sales_two_w
        if self.sales_two_y:
            if hasattr(self.sales_two_y, 'to_alipay_dict'):
                params['sales_two_y'] = self.sales_two_y.to_alipay_dict()
            else:
                params['sales_two_y'] = self.sales_two_y
        if self.seller_status:
            if hasattr(self.seller_status, 'to_alipay_dict'):
                params['seller_status'] = self.seller_status.to_alipay_dict()
            else:
                params['seller_status'] = self.seller_status
        if self.t_thirteen_wk_fba:
            if hasattr(self.t_thirteen_wk_fba, 'to_alipay_dict'):
                params['t_thirteen_wk_fba'] = self.t_thirteen_wk_fba.to_alipay_dict()
            else:
                params['t_thirteen_wk_fba'] = self.t_thirteen_wk_fba
        if self.t_three_m_fba_inv_value:
            if hasattr(self.t_three_m_fba_inv_value, 'to_alipay_dict'):
                params['t_three_m_fba_inv_value'] = self.t_three_m_fba_inv_value.to_alipay_dict()
            else:
                params['t_three_m_fba_inv_value'] = self.t_three_m_fba_inv_value
        if self.tenure:
            if hasattr(self.tenure, 'to_alipay_dict'):
                params['tenure'] = self.tenure.to_alipay_dict()
            else:
                params['tenure'] = self.tenure
        if self.ttm_cancellations:
            if hasattr(self.ttm_cancellations, 'to_alipay_dict'):
                params['ttm_cancellations'] = self.ttm_cancellations.to_alipay_dict()
            else:
                params['ttm_cancellations'] = self.ttm_cancellations
        if self.ttm_enforcements:
            if hasattr(self.ttm_enforcements, 'to_alipay_dict'):
                params['ttm_enforcements'] = self.ttm_enforcements.to_alipay_dict()
            else:
                params['ttm_enforcements'] = self.ttm_enforcements
        if self.ttm_feedback:
            if hasattr(self.ttm_feedback, 'to_alipay_dict'):
                params['ttm_feedback'] = self.ttm_feedback.to_alipay_dict()
            else:
                params['ttm_feedback'] = self.ttm_feedback
        if self.ttm_late_shipments:
            if hasattr(self.ttm_late_shipments, 'to_alipay_dict'):
                params['ttm_late_shipments'] = self.ttm_late_shipments.to_alipay_dict()
            else:
                params['ttm_late_shipments'] = self.ttm_late_shipments
        if self.ttm_neg_feedback:
            if hasattr(self.ttm_neg_feedback, 'to_alipay_dict'):
                params['ttm_neg_feedback'] = self.ttm_neg_feedback.to_alipay_dict()
            else:
                params['ttm_neg_feedback'] = self.ttm_neg_feedback
        if self.ttm_order_defects:
            if hasattr(self.ttm_order_defects, 'to_alipay_dict'):
                params['ttm_order_defects'] = self.ttm_order_defects.to_alipay_dict()
            else:
                params['ttm_order_defects'] = self.ttm_order_defects
        if self.ttm_orders:
            if hasattr(self.ttm_orders, 'to_alipay_dict'):
                params['ttm_orders'] = self.ttm_orders.to_alipay_dict()
            else:
                params['ttm_orders'] = self.ttm_orders
        if self.ttm_returns:
            if hasattr(self.ttm_returns, 'to_alipay_dict'):
                params['ttm_returns'] = self.ttm_returns.to_alipay_dict()
            else:
                params['ttm_returns'] = self.ttm_returns
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LendingDataList()
        if 'curr_fba_inv_value' in d:
            o.curr_fba_inv_value = d['curr_fba_inv_value']
        if 'currency' in d:
            o.currency = d['currency']
        if 'disbursements_eight_m' in d:
            o.disbursements_eight_m = d['disbursements_eight_m']
        if 'disbursements_eight_q' in d:
            o.disbursements_eight_q = d['disbursements_eight_q']
        if 'disbursements_eleven_m' in d:
            o.disbursements_eleven_m = d['disbursements_eleven_m']
        if 'disbursements_five_m' in d:
            o.disbursements_five_m = d['disbursements_five_m']
        if 'disbursements_five_q' in d:
            o.disbursements_five_q = d['disbursements_five_q']
        if 'disbursements_five_w' in d:
            o.disbursements_five_w = d['disbursements_five_w']
        if 'disbursements_four_m' in d:
            o.disbursements_four_m = d['disbursements_four_m']
        if 'disbursements_four_q' in d:
            o.disbursements_four_q = d['disbursements_four_q']
        if 'disbursements_four_w' in d:
            o.disbursements_four_w = d['disbursements_four_w']
        if 'disbursements_nine_m' in d:
            o.disbursements_nine_m = d['disbursements_nine_m']
        if 'disbursements_one_m' in d:
            o.disbursements_one_m = d['disbursements_one_m']
        if 'disbursements_one_q' in d:
            o.disbursements_one_q = d['disbursements_one_q']
        if 'disbursements_one_w' in d:
            o.disbursements_one_w = d['disbursements_one_w']
        if 'disbursements_one_y' in d:
            o.disbursements_one_y = d['disbursements_one_y']
        if 'disbursements_seven_m' in d:
            o.disbursements_seven_m = d['disbursements_seven_m']
        if 'disbursements_seven_q' in d:
            o.disbursements_seven_q = d['disbursements_seven_q']
        if 'disbursements_six_m' in d:
            o.disbursements_six_m = d['disbursements_six_m']
        if 'disbursements_six_q' in d:
            o.disbursements_six_q = d['disbursements_six_q']
        if 'disbursements_six_w' in d:
            o.disbursements_six_w = d['disbursements_six_w']
        if 'disbursements_ten_m' in d:
            o.disbursements_ten_m = d['disbursements_ten_m']
        if 'disbursements_three_m' in d:
            o.disbursements_three_m = d['disbursements_three_m']
        if 'disbursements_three_q' in d:
            o.disbursements_three_q = d['disbursements_three_q']
        if 'disbursements_three_w' in d:
            o.disbursements_three_w = d['disbursements_three_w']
        if 'disbursements_twelve_m' in d:
            o.disbursements_twelve_m = d['disbursements_twelve_m']
        if 'disbursements_two_m' in d:
            o.disbursements_two_m = d['disbursements_two_m']
        if 'disbursements_two_q' in d:
            o.disbursements_two_q = d['disbursements_two_q']
        if 'disbursements_two_w' in d:
            o.disbursements_two_w = d['disbursements_two_w']
        if 'disbursements_two_y' in d:
            o.disbursements_two_y = d['disbursements_two_y']
        if 'marketplace_country' in d:
            o.marketplace_country = d['marketplace_country']
        if 'offer_id' in d:
            o.offer_id = d['offer_id']
        if 'primary_category_last_three_month_sales_value' in d:
            o.primary_category_last_three_month_sales_value = d['primary_category_last_three_month_sales_value']
        if 'primary_product_category' in d:
            o.primary_product_category = d['primary_product_category']
        if 'report_card_data_date' in d:
            o.report_card_data_date = d['report_card_data_date']
        if 'sales_eight_m' in d:
            o.sales_eight_m = d['sales_eight_m']
        if 'sales_eight_q' in d:
            o.sales_eight_q = d['sales_eight_q']
        if 'sales_eleven_m' in d:
            o.sales_eleven_m = d['sales_eleven_m']
        if 'sales_five_m' in d:
            o.sales_five_m = d['sales_five_m']
        if 'sales_five_q' in d:
            o.sales_five_q = d['sales_five_q']
        if 'sales_five_w' in d:
            o.sales_five_w = d['sales_five_w']
        if 'sales_four_m' in d:
            o.sales_four_m = d['sales_four_m']
        if 'sales_four_q' in d:
            o.sales_four_q = d['sales_four_q']
        if 'sales_four_w' in d:
            o.sales_four_w = d['sales_four_w']
        if 'sales_nine_m' in d:
            o.sales_nine_m = d['sales_nine_m']
        if 'sales_one_m' in d:
            o.sales_one_m = d['sales_one_m']
        if 'sales_one_q' in d:
            o.sales_one_q = d['sales_one_q']
        if 'sales_one_w' in d:
            o.sales_one_w = d['sales_one_w']
        if 'sales_one_y' in d:
            o.sales_one_y = d['sales_one_y']
        if 'sales_seven_m' in d:
            o.sales_seven_m = d['sales_seven_m']
        if 'sales_seven_q' in d:
            o.sales_seven_q = d['sales_seven_q']
        if 'sales_six_m' in d:
            o.sales_six_m = d['sales_six_m']
        if 'sales_six_q' in d:
            o.sales_six_q = d['sales_six_q']
        if 'sales_six_w' in d:
            o.sales_six_w = d['sales_six_w']
        if 'sales_stability_score' in d:
            o.sales_stability_score = d['sales_stability_score']
        if 'sales_ten_m' in d:
            o.sales_ten_m = d['sales_ten_m']
        if 'sales_three_m' in d:
            o.sales_three_m = d['sales_three_m']
        if 'sales_three_q' in d:
            o.sales_three_q = d['sales_three_q']
        if 'sales_three_w' in d:
            o.sales_three_w = d['sales_three_w']
        if 'sales_twelve_m' in d:
            o.sales_twelve_m = d['sales_twelve_m']
        if 'sales_two_m' in d:
            o.sales_two_m = d['sales_two_m']
        if 'sales_two_q' in d:
            o.sales_two_q = d['sales_two_q']
        if 'sales_two_w' in d:
            o.sales_two_w = d['sales_two_w']
        if 'sales_two_y' in d:
            o.sales_two_y = d['sales_two_y']
        if 'seller_status' in d:
            o.seller_status = d['seller_status']
        if 't_thirteen_wk_fba' in d:
            o.t_thirteen_wk_fba = d['t_thirteen_wk_fba']
        if 't_three_m_fba_inv_value' in d:
            o.t_three_m_fba_inv_value = d['t_three_m_fba_inv_value']
        if 'tenure' in d:
            o.tenure = d['tenure']
        if 'ttm_cancellations' in d:
            o.ttm_cancellations = d['ttm_cancellations']
        if 'ttm_enforcements' in d:
            o.ttm_enforcements = d['ttm_enforcements']
        if 'ttm_feedback' in d:
            o.ttm_feedback = d['ttm_feedback']
        if 'ttm_late_shipments' in d:
            o.ttm_late_shipments = d['ttm_late_shipments']
        if 'ttm_neg_feedback' in d:
            o.ttm_neg_feedback = d['ttm_neg_feedback']
        if 'ttm_order_defects' in d:
            o.ttm_order_defects = d['ttm_order_defects']
        if 'ttm_orders' in d:
            o.ttm_orders = d['ttm_orders']
        if 'ttm_returns' in d:
            o.ttm_returns = d['ttm_returns']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ConversionDetail(object):

    def __init__(self):
        self._conversion_id = None
        self._conversion_name = None
        self._conversion_type = None
        self._conversion_type_name = None
        self._status = None

    @property
    def conversion_id(self):
        return self._conversion_id

    @conversion_id.setter
    def conversion_id(self, value):
        self._conversion_id = value
    @property
    def conversion_name(self):
        return self._conversion_name

    @conversion_name.setter
    def conversion_name(self, value):
        self._conversion_name = value
    @property
    def conversion_type(self):
        return self._conversion_type

    @conversion_type.setter
    def conversion_type(self, value):
        self._conversion_type = value
    @property
    def conversion_type_name(self):
        return self._conversion_type_name

    @conversion_type_name.setter
    def conversion_type_name(self, value):
        self._conversion_type_name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.conversion_id:
            if hasattr(self.conversion_id, 'to_alipay_dict'):
                params['conversion_id'] = self.conversion_id.to_alipay_dict()
            else:
                params['conversion_id'] = self.conversion_id
        if self.conversion_name:
            if hasattr(self.conversion_name, 'to_alipay_dict'):
                params['conversion_name'] = self.conversion_name.to_alipay_dict()
            else:
                params['conversion_name'] = self.conversion_name
        if self.conversion_type:
            if hasattr(self.conversion_type, 'to_alipay_dict'):
                params['conversion_type'] = self.conversion_type.to_alipay_dict()
            else:
                params['conversion_type'] = self.conversion_type
        if self.conversion_type_name:
            if hasattr(self.conversion_type_name, 'to_alipay_dict'):
                params['conversion_type_name'] = self.conversion_type_name.to_alipay_dict()
            else:
                params['conversion_type_name'] = self.conversion_type_name
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ConversionDetail()
        if 'conversion_id' in d:
            o.conversion_id = d['conversion_id']
        if 'conversion_name' in d:
            o.conversion_name = d['conversion_name']
        if 'conversion_type' in d:
            o.conversion_type = d['conversion_type']
        if 'conversion_type_name' in d:
            o.conversion_type_name = d['conversion_type_name']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniMiniappFavoriteextAddResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniMiniappFavoriteextAddResponse, self).__init__()
        self._success = None

    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniMiniappFavoriteextAddResponse, self).parse_response_content(response_content)
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LifeRecommendArticles(object):

    def __init__(self):
        self._article_id = None
        self._article_image = None
        self._article_link = None
        self._article_read_cnt = None
        self._article_source = None
        self._article_title = None

    @property
    def article_id(self):
        return self._article_id

    @article_id.setter
    def article_id(self, value):
        self._article_id = value
    @property
    def article_image(self):
        return self._article_image

    @article_image.setter
    def article_image(self, value):
        self._article_image = value
    @property
    def article_link(self):
        return self._article_link

    @article_link.setter
    def article_link(self, value):
        self._article_link = value
    @property
    def article_read_cnt(self):
        return self._article_read_cnt

    @article_read_cnt.setter
    def article_read_cnt(self, value):
        self._article_read_cnt = value
    @property
    def article_source(self):
        return self._article_source

    @article_source.setter
    def article_source(self, value):
        self._article_source = value
    @property
    def article_title(self):
        return self._article_title

    @article_title.setter
    def article_title(self, value):
        self._article_title = value


    def to_alipay_dict(self):
        params = dict()
        if self.article_id:
            if hasattr(self.article_id, 'to_alipay_dict'):
                params['article_id'] = self.article_id.to_alipay_dict()
            else:
                params['article_id'] = self.article_id
        if self.article_image:
            if hasattr(self.article_image, 'to_alipay_dict'):
                params['article_image'] = self.article_image.to_alipay_dict()
            else:
                params['article_image'] = self.article_image
        if self.article_link:
            if hasattr(self.article_link, 'to_alipay_dict'):
                params['article_link'] = self.article_link.to_alipay_dict()
            else:
                params['article_link'] = self.article_link
        if self.article_read_cnt:
            if hasattr(self.article_read_cnt, 'to_alipay_dict'):
                params['article_read_cnt'] = self.article_read_cnt.to_alipay_dict()
            else:
                params['article_read_cnt'] = self.article_read_cnt
        if self.article_source:
            if hasattr(self.article_source, 'to_alipay_dict'):
                params['article_source'] = self.article_source.to_alipay_dict()
            else:
                params['article_source'] = self.article_source
        if self.article_title:
            if hasattr(self.article_title, 'to_alipay_dict'):
                params['article_title'] = self.article_title.to_alipay_dict()
            else:
                params['article_title'] = self.article_title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LifeRecommendArticles()
        if 'article_id' in d:
            o.article_id = d['article_id']
        if 'article_image' in d:
            o.article_image = d['article_image']
        if 'article_link' in d:
            o.article_link = d['article_link']
        if 'article_read_cnt' in d:
            o.article_read_cnt = d['article_read_cnt']
        if 'article_source' in d:
            o.article_source = d['article_source']
        if 'article_title' in d:
            o.article_title = d['article_title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GFAOpenAPIAcceptanceResult(object):

    def __init__(self):
        self._acceptance_id = None
        self._need_retry = None
        self._out_business_no = None
        self._result_code = None
        self._result_message = None
        self._service_type = None
        self._solution_id = None
        self._sub_out_business_no = None

    @property
    def acceptance_id(self):
        return self._acceptance_id

    @acceptance_id.setter
    def acceptance_id(self, value):
        self._acceptance_id = value
    @property
    def need_retry(self):
        return self._need_retry

    @need_retry.setter
    def need_retry(self, value):
        self._need_retry = value
    @property
    def out_business_no(self):
        return self._out_business_no

    @out_business_no.setter
    def out_business_no(self, value):
        self._out_business_no = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_message(self):
        return self._result_message

    @result_message.setter
    def result_message(self, value):
        self._result_message = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value
    @property
    def solution_id(self):
        return self._solution_id

    @solution_id.setter
    def solution_id(self, value):
        self._solution_id = value
    @property
    def sub_out_business_no(self):
        return self._sub_out_business_no

    @sub_out_business_no.setter
    def sub_out_business_no(self, value):
        self._sub_out_business_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.acceptance_id:
            if hasattr(self.acceptance_id, 'to_alipay_dict'):
                params['acceptance_id'] = self.acceptance_id.to_alipay_dict()
            else:
                params['acceptance_id'] = self.acceptance_id
        if self.need_retry:
            if hasattr(self.need_retry, 'to_alipay_dict'):
                params['need_retry'] = self.need_retry.to_alipay_dict()
            else:
                params['need_retry'] = self.need_retry
        if self.out_business_no:
            if hasattr(self.out_business_no, 'to_alipay_dict'):
                params['out_business_no'] = self.out_business_no.to_alipay_dict()
            else:
                params['out_business_no'] = self.out_business_no
        if self.result_code:
            if hasattr(self.result_code, 'to_alipay_dict'):
                params['result_code'] = self.result_code.to_alipay_dict()
            else:
                params['result_code'] = self.result_code
        if self.result_message:
            if hasattr(self.result_message, 'to_alipay_dict'):
                params['result_message'] = self.result_message.to_alipay_dict()
            else:
                params['result_message'] = self.result_message
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        if self.solution_id:
            if hasattr(self.solution_id, 'to_alipay_dict'):
                params['solution_id'] = self.solution_id.to_alipay_dict()
            else:
                params['solution_id'] = self.solution_id
        if self.sub_out_business_no:
            if hasattr(self.sub_out_business_no, 'to_alipay_dict'):
                params['sub_out_business_no'] = self.sub_out_business_no.to_alipay_dict()
            else:
                params['sub_out_business_no'] = self.sub_out_business_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GFAOpenAPIAcceptanceResult()
        if 'acceptance_id' in d:
            o.acceptance_id = d['acceptance_id']
        if 'need_retry' in d:
            o.need_retry = d['need_retry']
        if 'out_business_no' in d:
            o.out_business_no = d['out_business_no']
        if 'result_code' in d:
            o.result_code = d['result_code']
        if 'result_message' in d:
            o.result_message = d['result_message']
        if 'service_type' in d:
            o.service_type = d['service_type']
        if 'solution_id' in d:
            o.solution_id = d['solution_id']
        if 'sub_out_business_no' in d:
            o.sub_out_business_no = d['sub_out_business_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenPublicAccountDeleteModel(object):

    def __init__(self):
        self._agreement_id = None
        self._bind_account_no = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def bind_account_no(self):
        return self._bind_account_no

    @bind_account_no.setter
    def bind_account_no(self, value):
        self._bind_account_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.bind_account_no:
            if hasattr(self.bind_account_no, 'to_alipay_dict'):
                params['bind_account_no'] = self.bind_account_no.to_alipay_dict()
            else:
                params['bind_account_no'] = self.bind_account_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicAccountDeleteModel()
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'bind_account_no' in d:
            o.bind_account_no = d['bind_account_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SourceMediaInfo import SourceMediaInfo
from alipay.aop.api.domain.SourceOffer import SourceOffer


class AlipaySocialBaseContentlibStandardcontentPublishModel(object):

    def __init__(self):
        self._public_id = None
        self._source_author = None
        self._source_content = None
        self._source_link = None
        self._source_media_infos = None
        self._source_offers = None
        self._source_publish_date = None
        self._source_summary = None
        self._source_title = None
        self._source_type = None

    @property
    def public_id(self):
        return self._public_id

    @public_id.setter
    def public_id(self, value):
        self._public_id = value
    @property
    def source_author(self):
        return self._source_author

    @source_author.setter
    def source_author(self, value):
        self._source_author = value
    @property
    def source_content(self):
        return self._source_content

    @source_content.setter
    def source_content(self, value):
        self._source_content = value
    @property
    def source_link(self):
        return self._source_link

    @source_link.setter
    def source_link(self, value):
        self._source_link = value
    @property
    def source_media_infos(self):
        return self._source_media_infos

    @source_media_infos.setter
    def source_media_infos(self, value):
        if isinstance(value, list):
            self._source_media_infos = list()
            for i in value:
                if isinstance(i, SourceMediaInfo):
                    self._source_media_infos.append(i)
                else:
                    self._source_media_infos.append(SourceMediaInfo.from_alipay_dict(i))
    @property
    def source_offers(self):
        return self._source_offers

    @source_offers.setter
    def source_offers(self, value):
        if isinstance(value, list):
            self._source_offers = list()
            for i in value:
                if isinstance(i, SourceOffer):
                    self._source_offers.append(i)
                else:
                    self._source_offers.append(SourceOffer.from_alipay_dict(i))
    @property
    def source_publish_date(self):
        return self._source_publish_date

    @source_publish_date.setter
    def source_publish_date(self, value):
        self._source_publish_date = value
    @property
    def source_summary(self):
        return self._source_summary

    @source_summary.setter
    def source_summary(self, value):
        self._source_summary = value
    @property
    def source_title(self):
        return self._source_title

    @source_title.setter
    def source_title(self, value):
        self._source_title = value
    @property
    def source_type(self):
        return self._source_type

    @source_type.setter
    def source_type(self, value):
        self._source_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.public_id:
            if hasattr(self.public_id, 'to_alipay_dict'):
                params['public_id'] = self.public_id.to_alipay_dict()
            else:
                params['public_id'] = self.public_id
        if self.source_author:
            if hasattr(self.source_author, 'to_alipay_dict'):
                params['source_author'] = self.source_author.to_alipay_dict()
            else:
                params['source_author'] = self.source_author
        if self.source_content:
            if hasattr(self.source_content, 'to_alipay_dict'):
                params['source_content'] = self.source_content.to_alipay_dict()
            else:
                params['source_content'] = self.source_content
        if self.source_link:
            if hasattr(self.source_link, 'to_alipay_dict'):
                params['source_link'] = self.source_link.to_alipay_dict()
            else:
                params['source_link'] = self.source_link
        if self.source_media_infos:
            if isinstance(self.source_media_infos, list):
                for i in range(0, len(self.source_media_infos)):
                    element = self.source_media_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.source_media_infos[i] = element.to_alipay_dict()
            if hasattr(self.source_media_infos, 'to_alipay_dict'):
                params['source_media_infos'] = self.source_media_infos.to_alipay_dict()
            else:
                params['source_media_infos'] = self.source_media_infos
        if self.source_offers:
            if isinstance(self.source_offers, list):
                for i in range(0, len(self.source_offers)):
                    element = self.source_offers[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.source_offers[i] = element.to_alipay_dict()
            if hasattr(self.source_offers, 'to_alipay_dict'):
                params['source_offers'] = self.source_offers.to_alipay_dict()
            else:
                params['source_offers'] = self.source_offers
        if self.source_publish_date:
            if hasattr(self.source_publish_date, 'to_alipay_dict'):
                params['source_publish_date'] = self.source_publish_date.to_alipay_dict()
            else:
                params['source_publish_date'] = self.source_publish_date
        if self.source_summary:
            if hasattr(self.source_summary, 'to_alipay_dict'):
                params['source_summary'] = self.source_summary.to_alipay_dict()
            else:
                params['source_summary'] = self.source_summary
        if self.source_title:
            if hasattr(self.source_title, 'to_alipay_dict'):
                params['source_title'] = self.source_title.to_alipay_dict()
            else:
                params['source_title'] = self.source_title
        if self.source_type:
            if hasattr(self.source_type, 'to_alipay_dict'):
                params['source_type'] = self.source_type.to_alipay_dict()
            else:
                params['source_type'] = self.source_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseContentlibStandardcontentPublishModel()
        if 'public_id' in d:
            o.public_id = d['public_id']
        if 'source_author' in d:
            o.source_author = d['source_author']
        if 'source_content' in d:
            o.source_content = d['source_content']
        if 'source_link' in d:
            o.source_link = d['source_link']
        if 'source_media_infos' in d:
            o.source_media_infos = d['source_media_infos']
        if 'source_offers' in d:
            o.source_offers = d['source_offers']
        if 'source_publish_date' in d:
            o.source_publish_date = d['source_publish_date']
        if 'source_summary' in d:
            o.source_summary = d['source_summary']
        if 'source_title' in d:
            o.source_title = d['source_title']
        if 'source_type' in d:
            o.source_type = d['source_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenApiValidStrategy(object):

    def __init__(self):
        self._gmt_invalid = None
        self._gmt_sign = None
        self._gmt_valid = None
        self._invalid_type = None
        self._valid_type = None

    @property
    def gmt_invalid(self):
        return self._gmt_invalid

    @gmt_invalid.setter
    def gmt_invalid(self, value):
        self._gmt_invalid = value
    @property
    def gmt_sign(self):
        return self._gmt_sign

    @gmt_sign.setter
    def gmt_sign(self, value):
        self._gmt_sign = value
    @property
    def gmt_valid(self):
        return self._gmt_valid

    @gmt_valid.setter
    def gmt_valid(self, value):
        self._gmt_valid = value
    @property
    def invalid_type(self):
        return self._invalid_type

    @invalid_type.setter
    def invalid_type(self, value):
        self._invalid_type = value
    @property
    def valid_type(self):
        return self._valid_type

    @valid_type.setter
    def valid_type(self, value):
        self._valid_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_invalid:
            if hasattr(self.gmt_invalid, 'to_alipay_dict'):
                params['gmt_invalid'] = self.gmt_invalid.to_alipay_dict()
            else:
                params['gmt_invalid'] = self.gmt_invalid
        if self.gmt_sign:
            if hasattr(self.gmt_sign, 'to_alipay_dict'):
                params['gmt_sign'] = self.gmt_sign.to_alipay_dict()
            else:
                params['gmt_sign'] = self.gmt_sign
        if self.gmt_valid:
            if hasattr(self.gmt_valid, 'to_alipay_dict'):
                params['gmt_valid'] = self.gmt_valid.to_alipay_dict()
            else:
                params['gmt_valid'] = self.gmt_valid
        if self.invalid_type:
            if hasattr(self.invalid_type, 'to_alipay_dict'):
                params['invalid_type'] = self.invalid_type.to_alipay_dict()
            else:
                params['invalid_type'] = self.invalid_type
        if self.valid_type:
            if hasattr(self.valid_type, 'to_alipay_dict'):
                params['valid_type'] = self.valid_type.to_alipay_dict()
            else:
                params['valid_type'] = self.valid_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenApiValidStrategy()
        if 'gmt_invalid' in d:
            o.gmt_invalid = d['gmt_invalid']
        if 'gmt_sign' in d:
            o.gmt_sign = d['gmt_sign']
        if 'gmt_valid' in d:
            o.gmt_valid = d['gmt_valid']
        if 'invalid_type' in d:
            o.invalid_type = d['invalid_type']
        if 'valid_type' in d:
            o.valid_type = d['valid_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TradePrecreateConfirmIndirectMerchantInfo(object):

    def __init__(self):
        self._agent_id = None
        self._agent_mcc = None
        self._agent_name = None
        self._city_code = None
        self._city_name_sc = None
        self._id = None
        self._mcc = None
        self._merchant_type = None
        self._name = None

    @property
    def agent_id(self):
        return self._agent_id

    @agent_id.setter
    def agent_id(self, value):
        self._agent_id = value
    @property
    def agent_mcc(self):
        return self._agent_mcc

    @agent_mcc.setter
    def agent_mcc(self, value):
        self._agent_mcc = value
    @property
    def agent_name(self):
        return self._agent_name

    @agent_name.setter
    def agent_name(self, value):
        self._agent_name = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def city_name_sc(self):
        return self._city_name_sc

    @city_name_sc.setter
    def city_name_sc(self, value):
        self._city_name_sc = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def mcc(self):
        return self._mcc

    @mcc.setter
    def mcc(self, value):
        self._mcc = value
    @property
    def merchant_type(self):
        return self._merchant_type

    @merchant_type.setter
    def merchant_type(self, value):
        self._merchant_type = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_id:
            if hasattr(self.agent_id, 'to_alipay_dict'):
                params['agent_id'] = self.agent_id.to_alipay_dict()
            else:
                params['agent_id'] = self.agent_id
        if self.agent_mcc:
            if hasattr(self.agent_mcc, 'to_alipay_dict'):
                params['agent_mcc'] = self.agent_mcc.to_alipay_dict()
            else:
                params['agent_mcc'] = self.agent_mcc
        if self.agent_name:
            if hasattr(self.agent_name, 'to_alipay_dict'):
                params['agent_name'] = self.agent_name.to_alipay_dict()
            else:
                params['agent_name'] = self.agent_name
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.city_name_sc:
            if hasattr(self.city_name_sc, 'to_alipay_dict'):
                params['city_name_sc'] = self.city_name_sc.to_alipay_dict()
            else:
                params['city_name_sc'] = self.city_name_sc
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.mcc:
            if hasattr(self.mcc, 'to_alipay_dict'):
                params['mcc'] = self.mcc.to_alipay_dict()
            else:
                params['mcc'] = self.mcc
        if self.merchant_type:
            if hasattr(self.merchant_type, 'to_alipay_dict'):
                params['merchant_type'] = self.merchant_type.to_alipay_dict()
            else:
                params['merchant_type'] = self.merchant_type
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TradePrecreateConfirmIndirectMerchantInfo()
        if 'agent_id' in d:
            o.agent_id = d['agent_id']
        if 'agent_mcc' in d:
            o.agent_mcc = d['agent_mcc']
        if 'agent_name' in d:
            o.agent_name = d['agent_name']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'city_name_sc' in d:
            o.city_name_sc = d['city_name_sc']
        if 'id' in d:
            o.id = d['id']
        if 'mcc' in d:
            o.mcc = d['mcc']
        if 'merchant_type' in d:
            o.merchant_type = d['merchant_type']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportTaxiOrderpriceQueryModel(object):

    def __init__(self):
        self._channel_type = None
        self._order_id = None
        self._request_time = None

    @property
    def channel_type(self):
        return self._channel_type

    @channel_type.setter
    def channel_type(self, value):
        self._channel_type = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def request_time(self):
        return self._request_time

    @request_time.setter
    def request_time(self, value):
        self._request_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_type:
            if hasattr(self.channel_type, 'to_alipay_dict'):
                params['channel_type'] = self.channel_type.to_alipay_dict()
            else:
                params['channel_type'] = self.channel_type
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.request_time:
            if hasattr(self.request_time, 'to_alipay_dict'):
                params['request_time'] = self.request_time.to_alipay_dict()
            else:
                params['request_time'] = self.request_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportTaxiOrderpriceQueryModel()
        if 'channel_type' in d:
            o.channel_type = d['channel_type']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'request_time' in d:
            o.request_time = d['request_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundCouponOrderDisburseResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundCouponOrderDisburseResponse, self).__init__()
        self._amount = None
        self._auth_no = None
        self._gmt_trans = None
        self._operation_id = None
        self._out_order_no = None
        self._out_request_no = None
        self._status = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def auth_no(self):
        return self._auth_no

    @auth_no.setter
    def auth_no(self, value):
        self._auth_no = value
    @property
    def gmt_trans(self):
        return self._gmt_trans

    @gmt_trans.setter
    def gmt_trans(self, value):
        self._gmt_trans = value
    @property
    def operation_id(self):
        return self._operation_id

    @operation_id.setter
    def operation_id(self, value):
        self._operation_id = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundCouponOrderDisburseResponse, self).parse_response_content(response_content)
        if 'amount' in response:
            self.amount = response['amount']
        if 'auth_no' in response:
            self.auth_no = response['auth_no']
        if 'gmt_trans' in response:
            self.gmt_trans = response['gmt_trans']
        if 'operation_id' in response:
            self.operation_id = response['operation_id']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class JfExportInstBillModel(object):

    def __init__(self):
        self._amount = None
        self._balance = None
        self._bill_date = None
        self._bill_fines = None
        self._bill_key = None
        self._extend_field = None
        self._inst_bill_no = None
        self._owner_name = None
        self._uniq_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def bill_date(self):
        return self._bill_date

    @bill_date.setter
    def bill_date(self, value):
        self._bill_date = value
    @property
    def bill_fines(self):
        return self._bill_fines

    @bill_fines.setter
    def bill_fines(self, value):
        self._bill_fines = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def inst_bill_no(self):
        return self._inst_bill_no

    @inst_bill_no.setter
    def inst_bill_no(self, value):
        self._inst_bill_no = value
    @property
    def owner_name(self):
        return self._owner_name

    @owner_name.setter
    def owner_name(self, value):
        self._owner_name = value
    @property
    def uniq_id(self):
        return self._uniq_id

    @uniq_id.setter
    def uniq_id(self, value):
        self._uniq_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.bill_date:
            if hasattr(self.bill_date, 'to_alipay_dict'):
                params['bill_date'] = self.bill_date.to_alipay_dict()
            else:
                params['bill_date'] = self.bill_date
        if self.bill_fines:
            if hasattr(self.bill_fines, 'to_alipay_dict'):
                params['bill_fines'] = self.bill_fines.to_alipay_dict()
            else:
                params['bill_fines'] = self.bill_fines
        if self.bill_key:
            if hasattr(self.bill_key, 'to_alipay_dict'):
                params['bill_key'] = self.bill_key.to_alipay_dict()
            else:
                params['bill_key'] = self.bill_key
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = self.extend_field.to_alipay_dict()
            else:
                params['extend_field'] = self.extend_field
        if self.inst_bill_no:
            if hasattr(self.inst_bill_no, 'to_alipay_dict'):
                params['inst_bill_no'] = self.inst_bill_no.to_alipay_dict()
            else:
                params['inst_bill_no'] = self.inst_bill_no
        if self.owner_name:
            if hasattr(self.owner_name, 'to_alipay_dict'):
                params['owner_name'] = self.owner_name.to_alipay_dict()
            else:
                params['owner_name'] = self.owner_name
        if self.uniq_id:
            if hasattr(self.uniq_id, 'to_alipay_dict'):
                params['uniq_id'] = self.uniq_id.to_alipay_dict()
            else:
                params['uniq_id'] = self.uniq_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = JfExportInstBillModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'balance' in d:
            o.balance = d['balance']
        if 'bill_date' in d:
            o.bill_date = d['bill_date']
        if 'bill_fines' in d:
            o.bill_fines = d['bill_fines']
        if 'bill_key' in d:
            o.bill_key = d['bill_key']
        if 'extend_field' in d:
            o.extend_field = d['extend_field']
        if 'inst_bill_no' in d:
            o.inst_bill_no = d['inst_bill_no']
        if 'owner_name' in d:
            o.owner_name = d['owner_name']
        if 'uniq_id' in d:
            o.uniq_id = d['uniq_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditSupplychainArAdmitQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSupplychainArAdmitQueryResponse, self).__init__()
        self._admit = None
        self._context = None

    @property
    def admit(self):
        return self._admit

    @admit.setter
    def admit(self, value):
        self._admit = value
    @property
    def context(self):
        return self._context

    @context.setter
    def context(self, value):
        self._context = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSupplychainArAdmitQueryResponse, self).parse_response_content(response_content)
        if 'admit' in response:
            self.admit = response['admit']
        if 'context' in response:
            self.context = response['context']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GFAOpenAPIParticipantInfo(object):

    def __init__(self):
        self._account_no = None
        self._account_type = None
        self._inst_code = None
        self._ip_role_id = None
        self._properties = None

    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def properties(self):
        return self._properties

    @properties.setter
    def properties(self, value):
        self._properties = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.properties:
            if hasattr(self.properties, 'to_alipay_dict'):
                params['properties'] = self.properties.to_alipay_dict()
            else:
                params['properties'] = self.properties
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GFAOpenAPIParticipantInfo()
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'properties' in d:
            o.properties = d['properties']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BFActivityFundInfo(object):

    def __init__(self):
        self._activity = None
        self._aggr_id = None
        self._agreement_id = None
        self._charge_code = None
        self._key = None
        self._platform_subsidy_id = None
        self._ratio = None
        self._seller_rate = None
        self._subsidy_mode = None
        self._subsidy_user = None
        self._term = None
        self._type = None

    @property
    def activity(self):
        return self._activity

    @activity.setter
    def activity(self, value):
        self._activity = value
    @property
    def aggr_id(self):
        return self._aggr_id

    @aggr_id.setter
    def aggr_id(self, value):
        self._aggr_id = value
    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def charge_code(self):
        return self._charge_code

    @charge_code.setter
    def charge_code(self, value):
        self._charge_code = value
    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value
    @property
    def platform_subsidy_id(self):
        return self._platform_subsidy_id

    @platform_subsidy_id.setter
    def platform_subsidy_id(self, value):
        self._platform_subsidy_id = value
    @property
    def ratio(self):
        return self._ratio

    @ratio.setter
    def ratio(self, value):
        self._ratio = value
    @property
    def seller_rate(self):
        return self._seller_rate

    @seller_rate.setter
    def seller_rate(self, value):
        self._seller_rate = value
    @property
    def subsidy_mode(self):
        return self._subsidy_mode

    @subsidy_mode.setter
    def subsidy_mode(self, value):
        self._subsidy_mode = value
    @property
    def subsidy_user(self):
        return self._subsidy_user

    @subsidy_user.setter
    def subsidy_user(self, value):
        self._subsidy_user = value
    @property
    def term(self):
        return self._term

    @term.setter
    def term(self, value):
        self._term = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity:
            if hasattr(self.activity, 'to_alipay_dict'):
                params['activity'] = self.activity.to_alipay_dict()
            else:
                params['activity'] = self.activity
        if self.aggr_id:
            if hasattr(self.aggr_id, 'to_alipay_dict'):
                params['aggr_id'] = self.aggr_id.to_alipay_dict()
            else:
                params['aggr_id'] = self.aggr_id
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.charge_code:
            if hasattr(self.charge_code, 'to_alipay_dict'):
                params['charge_code'] = self.charge_code.to_alipay_dict()
            else:
                params['charge_code'] = self.charge_code
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        if self.platform_subsidy_id:
            if hasattr(self.platform_subsidy_id, 'to_alipay_dict'):
                params['platform_subsidy_id'] = self.platform_subsidy_id.to_alipay_dict()
            else:
                params['platform_subsidy_id'] = self.platform_subsidy_id
        if self.ratio:
            if hasattr(self.ratio, 'to_alipay_dict'):
                params['ratio'] = self.ratio.to_alipay_dict()
            else:
                params['ratio'] = self.ratio
        if self.seller_rate:
            if hasattr(self.seller_rate, 'to_alipay_dict'):
                params['seller_rate'] = self.seller_rate.to_alipay_dict()
            else:
                params['seller_rate'] = self.seller_rate
        if self.subsidy_mode:
            if hasattr(self.subsidy_mode, 'to_alipay_dict'):
                params['subsidy_mode'] = self.subsidy_mode.to_alipay_dict()
            else:
                params['subsidy_mode'] = self.subsidy_mode
        if self.subsidy_user:
            if hasattr(self.subsidy_user, 'to_alipay_dict'):
                params['subsidy_user'] = self.subsidy_user.to_alipay_dict()
            else:
                params['subsidy_user'] = self.subsidy_user
        if self.term:
            if hasattr(self.term, 'to_alipay_dict'):
                params['term'] = self.term.to_alipay_dict()
            else:
                params['term'] = self.term
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BFActivityFundInfo()
        if 'activity' in d:
            o.activity = d['activity']
        if 'aggr_id' in d:
            o.aggr_id = d['aggr_id']
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'charge_code' in d:
            o.charge_code = d['charge_code']
        if 'key' in d:
            o.key = d['key']
        if 'platform_subsidy_id' in d:
            o.platform_subsidy_id = d['platform_subsidy_id']
        if 'ratio' in d:
            o.ratio = d['ratio']
        if 'seller_rate' in d:
            o.seller_rate = d['seller_rate']
        if 'subsidy_mode' in d:
            o.subsidy_mode = d['subsidy_mode']
        if 'subsidy_user' in d:
            o.subsidy_user = d['subsidy_user']
        if 'term' in d:
            o.term = d['term']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PkgAuthRelation import PkgAuthRelation


class AlipayCommerceLogisticsPkgauthrelationAuthtomeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceLogisticsPkgauthrelationAuthtomeQueryResponse, self).__init__()
        self._pkg_auth_relations = None

    @property
    def pkg_auth_relations(self):
        return self._pkg_auth_relations

    @pkg_auth_relations.setter
    def pkg_auth_relations(self, value):
        if isinstance(value, list):
            self._pkg_auth_relations = list()
            for i in value:
                if isinstance(i, PkgAuthRelation):
                    self._pkg_auth_relations.append(i)
                else:
                    self._pkg_auth_relations.append(PkgAuthRelation.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceLogisticsPkgauthrelationAuthtomeQueryResponse, self).parse_response_content(response_content)
        if 'pkg_auth_relations' in response:
            self.pkg_auth_relations = response['pkg_auth_relations']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CreditPayDiscountVO(object):

    def __init__(self):
        self._discount_desc = None
        self._discount_name = None
        self._full_discount_rate = None
        self._has_discount = None
        self._is_uneven_discount = None

    @property
    def discount_desc(self):
        return self._discount_desc

    @discount_desc.setter
    def discount_desc(self, value):
        self._discount_desc = value
    @property
    def discount_name(self):
        return self._discount_name

    @discount_name.setter
    def discount_name(self, value):
        self._discount_name = value
    @property
    def full_discount_rate(self):
        return self._full_discount_rate

    @full_discount_rate.setter
    def full_discount_rate(self, value):
        self._full_discount_rate = value
    @property
    def has_discount(self):
        return self._has_discount

    @has_discount.setter
    def has_discount(self, value):
        self._has_discount = value
    @property
    def is_uneven_discount(self):
        return self._is_uneven_discount

    @is_uneven_discount.setter
    def is_uneven_discount(self, value):
        self._is_uneven_discount = value


    def to_alipay_dict(self):
        params = dict()
        if self.discount_desc:
            if hasattr(self.discount_desc, 'to_alipay_dict'):
                params['discount_desc'] = self.discount_desc.to_alipay_dict()
            else:
                params['discount_desc'] = self.discount_desc
        if self.discount_name:
            if hasattr(self.discount_name, 'to_alipay_dict'):
                params['discount_name'] = self.discount_name.to_alipay_dict()
            else:
                params['discount_name'] = self.discount_name
        if self.full_discount_rate:
            if hasattr(self.full_discount_rate, 'to_alipay_dict'):
                params['full_discount_rate'] = self.full_discount_rate.to_alipay_dict()
            else:
                params['full_discount_rate'] = self.full_discount_rate
        if self.has_discount:
            if hasattr(self.has_discount, 'to_alipay_dict'):
                params['has_discount'] = self.has_discount.to_alipay_dict()
            else:
                params['has_discount'] = self.has_discount
        if self.is_uneven_discount:
            if hasattr(self.is_uneven_discount, 'to_alipay_dict'):
                params['is_uneven_discount'] = self.is_uneven_discount.to_alipay_dict()
            else:
                params['is_uneven_discount'] = self.is_uneven_discount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CreditPayDiscountVO()
        if 'discount_desc' in d:
            o.discount_desc = d['discount_desc']
        if 'discount_name' in d:
            o.discount_name = d['discount_name']
        if 'full_discount_rate' in d:
            o.full_discount_rate = d['full_discount_rate']
        if 'has_discount' in d:
            o.has_discount = d['has_discount']
        if 'is_uneven_discount' in d:
            o.is_uneven_discount = d['is_uneven_discount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ItemPropertyInfo(object):

    def __init__(self):
        self._property_key = None
        self._property_value_list = None

    @property
    def property_key(self):
        return self._property_key

    @property_key.setter
    def property_key(self, value):
        self._property_key = value
    @property
    def property_value_list(self):
        return self._property_value_list

    @property_value_list.setter
    def property_value_list(self, value):
        if isinstance(value, list):
            self._property_value_list = list()
            for i in value:
                self._property_value_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.property_key:
            if hasattr(self.property_key, 'to_alipay_dict'):
                params['property_key'] = self.property_key.to_alipay_dict()
            else:
                params['property_key'] = self.property_key
        if self.property_value_list:
            if isinstance(self.property_value_list, list):
                for i in range(0, len(self.property_value_list)):
                    element = self.property_value_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.property_value_list[i] = element.to_alipay_dict()
            if hasattr(self.property_value_list, 'to_alipay_dict'):
                params['property_value_list'] = self.property_value_list.to_alipay_dict()
            else:
                params['property_value_list'] = self.property_value_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemPropertyInfo()
        if 'property_key' in d:
            o.property_key = d['property_key']
        if 'property_value_list' in d:
            o.property_value_list = d['property_value_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsSumInsured(object):

    def __init__(self):
        self._default_value = None
        self._max_value = None
        self._min_value = None
        self._sum_insured_type = None
        self._sum_insureds = None

    @property
    def default_value(self):
        return self._default_value

    @default_value.setter
    def default_value(self, value):
        self._default_value = value
    @property
    def max_value(self):
        return self._max_value

    @max_value.setter
    def max_value(self, value):
        self._max_value = value
    @property
    def min_value(self):
        return self._min_value

    @min_value.setter
    def min_value(self, value):
        self._min_value = value
    @property
    def sum_insured_type(self):
        return self._sum_insured_type

    @sum_insured_type.setter
    def sum_insured_type(self, value):
        self._sum_insured_type = value
    @property
    def sum_insureds(self):
        return self._sum_insureds

    @sum_insureds.setter
    def sum_insureds(self, value):
        if isinstance(value, list):
            self._sum_insureds = list()
            for i in value:
                self._sum_insureds.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.default_value:
            if hasattr(self.default_value, 'to_alipay_dict'):
                params['default_value'] = self.default_value.to_alipay_dict()
            else:
                params['default_value'] = self.default_value
        if self.max_value:
            if hasattr(self.max_value, 'to_alipay_dict'):
                params['max_value'] = self.max_value.to_alipay_dict()
            else:
                params['max_value'] = self.max_value
        if self.min_value:
            if hasattr(self.min_value, 'to_alipay_dict'):
                params['min_value'] = self.min_value.to_alipay_dict()
            else:
                params['min_value'] = self.min_value
        if self.sum_insured_type:
            if hasattr(self.sum_insured_type, 'to_alipay_dict'):
                params['sum_insured_type'] = self.sum_insured_type.to_alipay_dict()
            else:
                params['sum_insured_type'] = self.sum_insured_type
        if self.sum_insureds:
            if isinstance(self.sum_insureds, list):
                for i in range(0, len(self.sum_insureds)):
                    element = self.sum_insureds[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sum_insureds[i] = element.to_alipay_dict()
            if hasattr(self.sum_insureds, 'to_alipay_dict'):
                params['sum_insureds'] = self.sum_insureds.to_alipay_dict()
            else:
                params['sum_insureds'] = self.sum_insureds
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsSumInsured()
        if 'default_value' in d:
            o.default_value = d['default_value']
        if 'max_value' in d:
            o.max_value = d['max_value']
        if 'min_value' in d:
            o.min_value = d['min_value']
        if 'sum_insured_type' in d:
            o.sum_insured_type = d['sum_insured_type']
        if 'sum_insureds' in d:
            o.sum_insureds = d['sum_insureds']
        return o


